;*****************************************************************************
;				NICST TOOL
;
;  RC-5 Part 2 test for TEB bands. Calculates the SNR and NEdT. Fits the SNR
;  to the OBC detla radiance (using a function with Powell's method) 
;  with or without weights of 1/std. This is done on a scan averaged basis..
;
;  Input:
;  1) Input file.
;
;  Output:
;  1) SNR[collect,band,HAM,detector,subsample]
;  2) SNR_1[collect,band,HAM,detector,subsample,scan]
;  3) snr_coeff_warm[band,HAM,detector,subsample,coefficients,not weighted or weighted,rsr]
;  4) snr_coeff_warm_error[band,HAM,detector,subsample,coefficients,not weighted or weighted,rsr]
;  5) snr_fit_warm[collect,band,HAM,detector,subsample,not weighted or weighted,rsr]
;  6) NEdL_warm[collect,b,HAM,detector,subsample,not weighted or weighted,rsr]
;  7) NEdT_warm[collect,band,HAM,detector,subsample,not weighted or weighted,rsr]
;  8) SNR_typ_warm[band,HAM,detector,subsample,not weighted or weighted,rsr]
;  9) NEdL_typ_warm[band,HAM,detector,subsample,not weighted or weighted,rsr]
;  10) NEdT_typ_warm[band,HAM,detector,subsample,not weighted or weighted,rsr]
;  11) snr_coeff_cool[band,HAM,detector,subsample,coefficients,not weighted or weighted,rsr]
;  12) snr_coeff_cool_error[band,HAM,detector,subsample,coefficients,not weighted or weighted,rsr]
;  13) snr_fit_cool[collect,band,HAM,detector,subsample,not weighted or weighted,rsr]
;  14) NEdL_cool[collect,b,HAM,detector,subsample,not weighted or weighted,rsr]
;  15) NEdT_cool[collect,band,HAM,detector,subsample,not weighted or weighted,rsr]
;  16) SNR_typ_cool[band,HAM,detector,subsample,not weighted or weighted,rsr]
;  17) NEdL_typ_cool[band,HAM,detector,subsample,not weighted or weighted,rsr]
;  18) NEdT_typ_cool[band,HAM,detector,subsample,not weighted or weighted,rsr]
;
;  v1.0 - 04/03/2008 - Jeff McIntire
;  v2.0 - 03/16/2009 - Jeff McIntire
;  v3.0 - 03/31/2009 - Jeff McIntire
;   -- added errors and changed to curvefit.
;*****************************************************************************

;*****************************************************************************
;  Functions for curvefit.
;*****************************************************************************

; SNR equal to the Delta radiance divided by sqrt of quadratic polynominal in delta radiance.
PRO curfunc1, X,A, F, pder

COMMON share,ncollects,b,id,ih,is,iscan,rsr,warm,cool
COMMON share_2,SNR_1,rad_OBC_scan_x,w,L_typ

F=X/sqrt(A[0]+A[1]*X+A[2]*X^2)
FOR i=0, n_elements(X)-1 DO BEGIN
    IF A[0]+A[1]*X[i]+A[2]*X[i]^2 LT 0.0 THEN F[i]=100000
    IF A[0]+A[1]*L_typ[b,0]+A[2]*L_typ[b,0]^2 LT 0.0 THEN F[i]=100000
ENDFOR

IF N_PARAMS() GE 4 THEN pder=[[-X/(2*sqrt(A[0]+A[1]*X+A[2]*X^2)^3)],[-X^2/(2*sqrt(A[0]+A[1]*X+A[2]*X^2)^3)],[-X^3/(2*sqrt(A[0]+A[1]*X+A[2]*X^2)^3)]]

END

; Quadratic polynomial.
PRO curfunc2, X,A, F, pder

F=A[0]+A[1]*X+A[2]*X^2

IF N_PARAMS() GE 4 THEN pder=[[replicate(1.0,n_elements(X))],[X],[X^2]]

;F=X/sqrt(A[0]+A[1]*X+A[2]*X^2)
;FOR i=0, n_elements(X)-1 DO BEGIN
;    IF A[0]+A[1]*X[i]+A[2]*X[i]^2 LT 0.0 THEN F[i]=100000
;    IF A[0]+A[1]*L_typ[b,0]+A[2]*L_typ[b,0]^2 LT 0.0 THEN F[i]=100000
;ENDFOR

;IF N_PARAMS() GE 4 THEN pder=[[-X/(2*sqrt(A[0]+A[1]*X+A[2]*X^2)^3)],[-X^2/(2*sqrt(A[0]+A[1]*X+A[2]*X^2)^3)],[-X^3/(2*sqrt(A[0]+A[1]*X+A[2]*X^2)^3)]]

END

;*****************************************************************************
;  Main program.
;*****************************************************************************

PRO RC5_OBC_SNR_NEdT, infile

nlines=File_Lines(infile)
header=strarr(1)
inpath=strarr(1)		; Input path.
outpath=strarr(1)		; Output path.
rvs_in=strarr(1)		; RVS .sav file.
param_in=strarr(1)		; EDU coeff .sav file.
rsrpath=strarr(1)		; RSR .sav file.
maxscan=intarr(1)               ; # of scans

openr,lun,infile,/Get_Lun	
readf,lun,header	
readf,lun,inpath
readf,lun,outpath
readf,lun,rvs_in
readf,lun,param_in
readf,lun,rsrpath
readf,lun,maxscan
Free_Lun,lun

maxscan=maxscan[0]

a2=strsplit(outpath,'/',/Extract)
a3=N_ELEMENTS(a2)

restore,'general.TEB.2.sav'
restore,outpath+a2[a3-3]+'.'+a2[a3-2]+'.'+a2[a3-1]+'.dn.sav'
restore,outpath+a2[a3-3]+'.'+a2[a3-2]+'.'+a2[a3-1]+'.rad.sav'
restore,outpath+a2[a3-3]+'.'+a2[a3-2]+'.'+a2[a3-1]+'.rg.sav'
restore,outpath+a2[a3-3]+'.'+a2[a3-2]+'.'+a2[a3-1]+'.temp.sav'

outfile=outpath+a2[a3-3]+'.'+a2[a3-2]+'.'+a2[a3-1]+'.snr.sav'

COMMON share,ncollects,b,id,ih,is,iscan,rsr,warm,cool
COMMON share_2,SNR_1,rad_OBC_scan_x,w,L_typ

;*****************************************************************************
;  Reform the radiance to get rid of extra zeros and scan average.
;*****************************************************************************

rad_OBC=dblarr(ncollects,nbands,nham,maxdet,maxsubsets,2)
FOR b=0, nbands-1 DO BEGIN
    FOR is=0, subsets[b]-1 DO BEGIN
        FOR ih=0, nham-1 DO BEGIN
            FOR id=0, detectors[b]-1 DO BEGIN
                FOR col=0, ncollects-1 DO BEGIN
                    FOR rsr=0, 1 DO BEGIN
                        index2=WHERE(abs(rad_OBC_scan[col,b,ih,id,is,*,rsr]) GT 0.01, arr2)
                        rad_OBC[col,b,ih,id,is,rsr]=mean(rad_OBC_scan[col,b,ih,id,is,index2,rsr])
                    ENDFOR
                ENDFOR
            ENDFOR
        ENDFOR
    ENDFOR
ENDFOR

;*****************************************************************************
;  SNR definitions.
;*****************************************************************************

SNR=dblarr(ncollects,nbands,nham,maxdet,maxsubsets,3)
sigma_SNR=dblarr(ncollects,nbands,nham,maxdet,maxsubsets,3)

;*****************************************************************************
;  Calculate the SNR (scan method).
;*****************************************************************************

SNR_1=dblarr(ncollects,nbands,nham,maxdet,maxsubsets,maxscan)
SNR_2=dblarr(ncollects,nbands,nham,maxdet,maxsubsets)
SNR_3=dblarr(ncollects,nbands,nham,maxdet,maxsubsets,maxscan)

FOR col=0, ncollects-1 DO BEGIN
    FOR b=0, nbands-1 DO BEGIN
        FOR ih=0, nham-1 DO BEGIN
            FOR is=0, subsets[b]-1 DO BEGIN
                FOR id=0, detectors[b]-1 DO BEGIN
                    SNR_1[col,b,ih,id,is,0:maxscan-1]=dn_col[col,b,ih,id,is,1,0:maxscan-1,2]/std_col[col,b,ih,id,is,1,0:maxscan-1,2]
                    FOR iscans=0, maxscan-1 DO BEGIN
                        IF std_col[col,b,ih,id,is,1,iscans,2] EQ 0 THEN SNR_1[col,b,ih,id,is,iscans]=0
                    ENDFOR
                    
                    SNR_2[col,b,ih,id,is]=sig_mean(SNR_1[col,b,ih,id,is,0:maxscan-1],3,1)
                    FOR iscans=0, maxscan-1 DO SNR_3[col,b,ih,id,is,iscans]=(SNR_1[col,b,ih,id,is,iscans]-SNR_2[col,b,ih,id,is])^2
                    
                    SNR[col,b,ih,id,is,0]=sig_mean(SNR_1[col,b,ih,id,is,0:maxscan-1],3,1)
                    sigma_SNR[col,b,ih,id,is,0]=sqrt(sig_mean(SNR_3[col,b,ih,id,is,0:maxscan-1],3,1))
                ENDFOR
            ENDFOR
        ENDFOR
    ENDFOR
ENDFOR

;*****************************************************************************
;  Calculate the SNR (sample method).
;*****************************************************************************

SNR_1=dblarr(ncollects,nbands,nham,maxdet,maxsubsets,96)
SNR_2=dblarr(ncollects,nbands,nham,maxdet,maxsubsets)
SNR_3=dblarr(ncollects,nbands,nham,maxdet,maxsubsets,96)

FOR col=0, ncollects-1 DO BEGIN
    FOR b=0, nbands-1 DO BEGIN
        IF band_type[b] EQ 1 THEN max_frame=96
        IF band_type[b] EQ 0 THEN max_frame=48
        FOR ih=0, nham-1 DO BEGIN
            FOR is=0, subsets[b]-1 DO BEGIN
                FOR id=0, detectors[b]-1 DO BEGIN
                    SNR_1[col,b,ih,id,is,0:max_frame-1]=dn_col_2[col,b,ih,id,is,1,0:max_frame-1,2]/std_col_2[col,b,ih,id,is,1,0:max_frame-1,2]
                    FOR f=0, max_frame-1 DO BEGIN
                        IF std_col_2[col,b,ih,id,is,1,f] EQ 0 THEN SNR_1[col,b,ih,id,is,f]=0
                    ENDFOR
                    
                    SNR_2[col,b,ih,id,is]=sig_mean(SNR_1[col,b,ih,id,is,0:max_frame-1],3,1)
                    FOR f=0, max_frame-1 DO SNR_3[col,b,ih,id,is,f]=(SNR_1[col,b,ih,id,is,f]-SNR_2[col,b,ih,id,is])^2
                    
                    SNR[col,b,ih,id,is,1]=sig_mean(SNR_1[col,b,ih,id,is,0:max_frame-1],3,1)
                    sigma_SNR[col,b,ih,id,is,1]=sqrt(sig_mean(SNR_3[col,b,ih,id,is,0:max_frame-1],3,1))
                ENDFOR
            ENDFOR
        ENDFOR
    ENDFOR
ENDFOR

;*****************************************************************************
;  Calculate the SNR (overall method).
;*****************************************************************************

SNR[*,*,*,*,*,2]=dn_obc[*,*,*,*,*,1,2]/std_obc[*,*,*,*,*,1,2]
sigma_SNR[*,*,*,*,*,2]=std_obc[*,*,*,*,*,1,2]

;*****************************************************************************
;  Find warm-up and cool-down collects.
;*****************************************************************************

F=findgen(ncollects)
FOR ih=0, nham-1 DO BEGIN
    max_col=WHERE(T_obc[ih,*] EQ max(T_obc[ih,*]))
    warm=WHERE(F[0:ncollects-1] LE max_col[0])
    cool=WHERE(F[0:ncollects-1] GT max_col[0])
ENDFOR

;*****************************************************************************
;  Powell's method and ploy_fit (cubic) for fitting SNR to BCS radiance.
;*****************************************************************************

w=dblarr(ncollects)

snr_coeff_warm=dblarr(nbands,nham,maxdet,maxsubsets,3,2,2)
snr_coeff_cool=dblarr(nbands,nham,maxdet,maxsubsets,3,2,2)
snr_coeff_warm_error=dblarr(nbands,nham,maxdet,maxsubsets,3,2,2)
snr_coeff_cool_error=dblarr(nbands,nham,maxdet,maxsubsets,3,2,2)
snr_fit_warm=dblarr(ncollects,nbands,nham,maxdet,maxsubsets,2,2)
snr_fit_cool=dblarr(ncollects,nbands,nham,maxdet,maxsubsets,2,2)

FOR rsr=0, 1 DO BEGIN
    FOR ifit=0, 1 DO BEGIN
        FOR b=0, nbands-1 DO BEGIN
            FOR is=0, subsets[b]-1 DO BEGIN
                FOR ih=0, nham-1 DO BEGIN
                    FOR id=0, detectors[b]-1 DO BEGIN

                        ; Gaussian weighting.
                        IF ifit EQ 0 THEN w[*]=1.0
                        IF ifit EQ 1 THEN w[*]=1/sigma_SNR[*,b,ih,id,is]^2

                        rad_OBC_warm=[0.0,rad_OBC[warm,b,ih,id,is,rsr]]*0.4444
                        rad_OBC_cool=[0.0,rad_OBC[cool,b,ih,id,is,rsr]]*0.4444
                        SNR_warm=[0.0,SNR[warm,b,ih,id,is,0]]
                        SNR_cool=[0.0,SNR[cool,b,ih,id,is,0]]
                        w_warm=[min(w[warm]),w[warm]]
                        w_cool=[min(w[cool]),w[cool]]

                        ; Warm-up collects.
                        P1=[.000001,.000001,.000001]
                        yfit=curvefit(rad_OBC_warm,SNR_warm,w_warm,P1,SIGMA1,/DOUBLE,FUNCTION_NAME='curfunc1')
                        snr_coeff_warm[b,ih,id,is,*,ifit,rsr]=P1[*]
                        snr_coeff_warm_error[b,ih,id,is,*,ifit,rsr]=SIGMA1[*]

                        ; Cool-down collects.
                        P2=[.000001,.000001,.000001]
                        yfit=curvefit(rad_OBC_cool,SNR_cool,w_cool,P2,SIGMA2,/DOUBLE,FUNCTION_NAME='curfunc2')
                        snr_coeff_cool[b,ih,id,is,*,ifit,rsr]=P2[*]
                        snr_coeff_cool_error[b,ih,id,is,*,ifit,rsr]=SIGMA2[*]
                        
                        print,rsr,ifit,b,id,ih,is,P1[0],P1[1],P1[2],P2[0],P2[1],P2[2]
                        
                        ; Fitting Residuals.
                        snr_fit_warm[warm,b,ih,id,is,ifit,rsr] $
                          =(SNR[warm,b,ih,id,is,0]-(rad_OBC[warm,b,ih,id,is,rsr]*0.4444) $
                            /sqrt(P1[0]+P1[1]*(rad_OBC[warm,b,ih,id,is,rsr]*0.4444) $
                                  +P1[2]*(rad_OBC[warm,b,ih,id,is,rsr]*0.4444)^2))/SNR[warm,b,ih,id,is,0]
                    ;    snr_fit_cool[cool,b,ih,id,is,ifit,rsr] $
                    ;      =(SNR[cool,b,ih,id,is,0]-(rad_OBC[cool,b,ih,id,is,rsr]*0.4444) $
                    ;        /sqrt(P2[0]+P2[1]*(rad_OBC[cool,b,ih,id,is,rsr]*0.4444) $
                    ;              +P2[2]*(rad_OBC[cool,b,ih,id,is,rsr]*0.4444)^2))/SNR[cool,b,ih,id,is,0]
                        snr_fit_cool[cool,b,ih,id,is,ifit,rsr] $
                          =(SNR[cool,b,ih,id,is,0]-(P2[0]+P2[1]*(rad_OBC[cool,b,ih,id,is,rsr]*0.4444) $
                                                    +P2[2]*(rad_OBC[cool,b,ih,id,is,rsr]*0.4444)^2))/SNR[cool,b,ih,id,is,0]
                    ENDFOR
                ENDFOR
            ENDFOR
        ENDFOR
    ENDFOR
ENDFOR

;*****************************************************************************
;  Calulate the NEdL and NEdT. Extrapolate to T_typ.
;*****************************************************************************

NEdL_warm=dblarr(ncollects,nbands,nham,maxdet,maxsubsets,2,2)
NEdL_cool=dblarr(ncollects,nbands,nham,maxdet,maxsubsets,2,2)
NEdT_warm=dblarr(ncollects,nbands,nham,maxdet,maxsubsets,2,2)
NEdT_cool=dblarr(ncollects,nbands,nham,maxdet,maxsubsets,2,2)
SNR_typ_warm=dblarr(nbands,nham,maxdet,maxsubsets,2,2)
SNR_typ_cool=dblarr(nbands,nham,maxdet,maxsubsets,2,2)
NEdL_typ_warm=dblarr(nbands,nham,maxdet,maxsubsets,2,2)
NEdL_typ_cool=dblarr(nbands,nham,maxdet,maxsubsets,2,2)
NEdT_typ_warm=dblarr(nbands,nham,maxdet,maxsubsets,2,2)
NEdT_typ_cool=dblarr(nbands,nham,maxdet,maxsubsets,2,2)

FOR rsr=0, 1 DO BEGIN
    FOR ifit=0, 1 DO BEGIN
        FOR b=0, nbands-1 DO BEGIN
            FOR is=0, subsets[b]-1 DO BEGIN
                FOR ih=0, nham-1 DO BEGIN
                    FOR id=0, detectors[b]-1 DO BEGIN

                        ; Warm-up.
                        NEdL_warm[warm,b,ih,id,is,ifit,rsr]=rad_OBC[warm,b,ih,id,is,rsr]*0.4444/SNR[warm,b,ih,id,is,0]
                        NEdT_warm[warm,b,ih,id,is,ifit,rsr]=NEdL_warm[warm,b,ih,id,is,ifit,rsr]/Planck_deriv(T_bcs[warm],lambda_center[b])
                            
                        SNR_typ_warm[b,ih,id,is,ifit,rsr]=L_typ[b,0] $
                          /sqrt(snr_coeff_warm[b,ih,id,is,0,ifit,rsr]+snr_coeff_warm[b,ih,id,is,1,ifit,rsr]*L_typ[b,0] $
                                +snr_coeff_warm[b,ih,id,is,2,ifit,rsr]*L_typ[b,0]^2)
                        NEdL_typ_warm[b,ih,id,is,ifit,rsr]= $
                          sqrt(snr_coeff_warm[b,ih,id,is,0,ifit,rsr]+snr_coeff_warm[b,ih,id,is,1,ifit,rsr]*L_typ[b,0] $
                               +snr_coeff_warm[b,ih,id,is,2,ifit,rsr]*L_typ[b,0]^2)
                        NEdT_typ_warm[b,ih,id,is,ifit,rsr]=NEdL_typ_warm[b,ih,id,is,ifit,rsr]/Planck_deriv(T_typ[b],lambda_center[b])
                        
                        ; Cool-down.
                        NEdL_cool[cool,b,ih,id,is,ifit,rsr]=rad_OBC[cool,b,ih,id,is,rsr]*0.4444/SNR[cool,b,ih,id,is,0]
                        NEdT_cool[cool,b,ih,id,is,ifit,rsr]=NEdL_cool[cool,b,ih,id,is,ifit,rsr]/Planck_deriv(T_bcs[cool],lambda_center[b])
                        
                  ;      SNR_typ_cool[b,ih,id,is,ifit,rsr]=L_typ[b,0] $
                  ;        /sqrt(snr_coeff_cool[b,ih,id,is,0,ifit,rsr]+snr_coeff_cool[b,ih,id,is,1,ifit,rsr]*L_typ[b,0] $
                  ;              +snr_coeff_cool[b,ih,id,is,2,ifit,rsr]*L_typ[b,0]^2)
                  ;      NEdL_typ_cool[b,ih,id,is,ifit,rsr]= $
                  ;        sqrt(snr_coeff_cool[b,ih,id,is,0,ifit,rsr]+snr_coeff_cool[b,ih,id,is,1,ifit,rsr]*L_typ[b,0] $
                  ;             +snr_coeff_cool[b,ih,id,is,2,ifit,rsr]*L_typ[b,0]^2)
                  ;      NEdT_typ_cool[b,ih,id,is,ifit,rsr]=NEdL_typ_cool[b,ih,id,is,ifit,rsr]/Planck_deriv(T_typ[b],lambda_center[b])
                        
                        SNR_typ_cool[b,ih,id,is,ifit,rsr]= $
                          (snr_coeff_cool[b,ih,id,is,0,ifit,rsr]+snr_coeff_cool[b,ih,id,is,1,ifit,rsr]*L_typ[b,0] $
                           +snr_coeff_cool[b,ih,id,is,2,ifit,rsr]*L_typ[b,0]^2)
                        NEdL_typ_cool[b,ih,id,is,ifit,rsr]=L_typ[b,0] $
                          /(snr_coeff_cool[b,ih,id,is,0,ifit,rsr]+snr_coeff_cool[b,ih,id,is,1,ifit,rsr]*L_typ[b,0] $
                            +snr_coeff_cool[b,ih,id,is,2,ifit,rsr]*L_typ[b,0]^2)
                        NEdT_typ_cool[b,ih,id,is,ifit,rsr]=NEdL_typ_cool[b,ih,id,is,ifit,rsr]/Planck_deriv(T_typ[b],lambda_center[b])
                    ENDFOR
                ENDFOR
            ENDFOR
        ENDFOR
    ENDFOR
ENDFOR

;*****************************************************************************
;  Output SNR and NEdT to txt and sav files.
;*****************************************************************************

outfile1=outpath+a2[a3-3]+'.'+a2[a3-2]+'.'+a2[a3-1]+'.snr_typ_warm.txt'
outfile2=outpath+a2[a3-3]+'.'+a2[a3-2]+'.'+a2[a3-1]+'.snr_typ_cool.txt'
outfile3=outpath+a2[a3-3]+'.'+a2[a3-2]+'.'+a2[a3-1]+'.NEdT_typ_warm.txt'
outfile4=outpath+a2[a3-3]+'.'+a2[a3-2]+'.'+a2[a3-1]+'.NEdT_typ_cool.txt'

fmt_1='(i3, 5x, i2, 5x, f, 5x, f, 5x, f, 5x, f, 5x, f, 5x, f, 5x, f, 5x, f)'

openw,lun,outfile1,/get_lun
printf,lun,'Warm-up Signal to Noise Ratio (SNR) at T_typ (averaged over subsample and scan, with weighted fits with RSR)'
printf,lun,'HAM      DET     I4        I5       M12       M13        M14      M15      M16A      M16B'
FOR ih=0, nham-1 DO BEGIN
    FOR id=0, maxdet-1 DO BEGIN
        IF id LT 16 THEN printf,lun,format=fmt_1,ih,id,mean(SNR_typ_warm[0,ih,id,0:1,1,0]), $
          mean(SNR_typ_warm[1,ih,id,0:1,1,0]),SNR_typ_warm[2,ih,id,0,1,0],SNR_typ_warm[3,ih,id,0,1,0], $
          SNR_typ_warm[4,ih,id,0,1,0],SNR_typ_warm[5,ih,id,0,1,0],SNR_typ_warm[6,ih,id,0,1,0],SNR_typ_warm[7,ih,id,0,1,0]
        IF id GE 16 THEN printf,lun,format=fmt_1,ih,id,mean(SNR_typ_warm[0,ih,id,0:1,1,0]), $
          mean(SNR_typ_warm[1,ih,id,0:1,1,0]),0.0,0.0,0.0,0.0,0.0,0.0
    ENDFOR
ENDFOR
free_lun,lun

openw,lun,outfile2,/get_lun
printf,lun,'Cool-down Signal to Noise Ratio (SNR) at T_typ (averaged over subsample and scan, with weighted fits with RSR)'
printf,lun,'HAM      DET     I4        I5       M12       M13        M14      M15      M16A      M16B'
FOR ih=0, nham-1 DO BEGIN
    FOR id=0, maxdet-1 DO BEGIN
        IF id LT 16 THEN printf,lun,format=fmt_1,ih,id,mean(SNR_typ_cool[0,ih,id,0:1,1,0]), $
          mean(SNR_typ_cool[1,ih,id,0:1,1,0]),SNR_typ_cool[2,ih,id,0,1,0],SNR_typ_cool[3,ih,id,0,1,0], $
          SNR_typ_cool[4,ih,id,0,1,0],SNR_typ_cool[5,ih,id,0,1,0],SNR_typ_cool[6,ih,id,0,1,0],SNR_typ_cool[7,ih,id,0,1,0]
        IF id GE 16 THEN printf,lun,format=fmt_1,ih,id,mean(SNR_typ_cool[0,ih,id,0:1,1,0]), $
          mean(SNR_typ_cool[1,ih,id,0:1,1,0]),0.0,0.0,0.0,0.0,0.0,0.0
    ENDFOR
ENDFOR
free_lun,lun

openw,lun,outfile3,/get_lun
printf,lun,'Warm-up Noise Equivalent detla Temperature (NEdT) at T_typ (averaged over subsample and scan, with weighted fits with RSR)'
printf,lun,'HAM      DET     I4        I5       M12       M13        M14      M15      M16A      M16B'
FOR ih=0, nham-1 DO BEGIN
    FOR id=0, maxdet-1 DO BEGIN
        IF id LT 16 THEN printf,lun,format=fmt_1,ih,id,mean(NEdT_typ_warm[0,ih,id,0:1,1,0]), $
          mean(NEdT_typ_warm[1,ih,id,0:1,1,0]),NEdT_typ_warm[2,ih,id,0,1,0],NEdT_typ_warm[3,ih,id,0,1,0], $
          NEdT_typ_warm[4,ih,id,0,1,0],NEdT_typ_warm[5,ih,id,0,1,0],NEdT_typ_warm[6,ih,id,0,1,0],NEdT_typ_warm[7,ih,id,0,1,0]
        IF id GE 16 THEN printf,lun,format=fmt_1,ih,id,mean(NEdT_typ_warm[0,ih,id,0:1,1,0]), $
          mean(NEdT_typ_warm[1,ih,id,0:1,1,0]),0.0,0.0,0.0,0.0,0.0,0.0
    ENDFOR
ENDFOR
free_lun,lun

openw,lun,outfile4,/get_lun
printf,lun,'Cool-down Noise Equivalent detla Temperature (NEdT) at T_typ (averaged over subsample and scan, with weighted fits with RSR)'
printf,lun,'HAM      DET     I4        I5       M12       M13        M14      M15      M16A      M16B'
FOR ih=0, nham-1 DO BEGIN
    FOR id=0, maxdet-1 DO BEGIN
        IF id LT 16 THEN printf,lun,format=fmt_1,ih,id,mean(NEdT_typ_cool[0,ih,id,0:1,1,0]), $
          mean(NEdT_typ_cool[1,ih,id,0:1,1,0]),NEdT_typ_cool[2,ih,id,0,1,0],NEdT_typ_cool[3,ih,id,0,1,0], $
          NEdT_typ_cool[4,ih,id,0,1,0],NEdT_typ_cool[5,ih,id,0,1,0],NEdT_typ_cool[6,ih,id,0,1,0],NEdT_typ_cool[7,ih,id,0,1,0]
        IF id GE 16 THEN printf,lun,format=fmt_1,ih,id,mean(NEdT_typ_cool[0,ih,id,0:1,1,0]), $
          mean(NEdT_typ_cool[1,ih,id,0:1,1,0]),0.0,0.0,0.0,0.0,0.0,0.0
    ENDFOR
ENDFOR
free_lun,lun
close,lun,/file,/all

save,/compress,SNR_1,SNR,snr_coeff_warm,snr_coeff_cool,snr_coeff_warm_error,snr_coeff_cool_error,snr_fit_warm,snr_fit_cool,NEdL_warm,NEdL_cool, $
  NEdT_warm,NEdT_cool,SNR_typ_warm,SNR_typ_cool,NEdL_typ_warm,NEdL_typ_cool,NEdT_typ_warm,NEdT_typ_cool,filename=outfile

;*****************************************************************************
;  Plot the SNR and NEdT at Ttyp
;*****************************************************************************

NEDT_spec=[[2.5,1.5,0.396,0.107,0.091,0.07,0.072,0.072],[0,0,0,0.423,0,0,0,0]]

set_multicolor,xsave,ysave,psave,chname,lcol,symbol,red,green,blue
set_plot,'ps'
outfname=outpath+a2[a3-3]+'.'+a2[a3-2]+'.'+a2[a3-1]+'.SNR_NEdT.ps'
device,/landscape,filename=outfname,/color
!p.multi=[0,1,1]
!p.position=0

G=findgen(40)
FOR b=0, nbands-1 DO BEGIN
    title1='SNR at T_typ (warm-up)'
    title2=band_name[b]
    
    ymax=max(SNR_typ_warm[b,0,0:detectors[b]-1,0,1,0],min=ymin)
        
    plot,G[0:detectors[b]-1]+1,SNR_typ_warm[b,0,0:detectors[b]-1,0,1,0],xtit='Detector',ytit='SNR @ T_typ',yrange=[ymin,ymax], $
      xrange=[0,detectors[b]+2],title=title2,charsize=1.2,charthick=5,thick=3,/nodata
    
    oplot,G[0:detectors[b]-1]+1,SNR_typ_warm[b,0,0:detectors[b]-1,0,1,0],symsize=1,color=lcol[0],psym=symbol[0],thick=3

    XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
ENDFOR

FOR b=0, nbands-1 DO BEGIN
    title1='NEdT at T_typ (warm-up)'
    title2=band_name[b]
    
    ymax=max(NEDT_spec[b,0]*1.1)
    ymin=0.0
        
    plot,G[0:detectors[b]-1]+1,NEdT_typ_warm[b,0,0:detectors[b]-1,0,1,0],xtit='Detector',ytit='NEdT @ T_typ',yrange=[ymin,ymax], $
      xrange=[0,detectors[b]+2],title=title2,charsize=1.2,charthick=5,thick=3,/nodata
    
    oplot,G[0:detectors[b]-1]+1,NEdT_typ_warm[b,0,0:detectors[b]-1,0,1,0],symsize=1,color=lcol[0],psym=symbol[0],thick=3
    oplot,[0.,40.],[mean(NEdT_spec[b,0]),mean(NEdT_spec[b,0])],linestyle=2,color=1,thick=5

    XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
ENDFOR

FOR b=0, nbands-1 DO BEGIN
    title1='SNR at T_typ (cool-down)'
    title2=band_name[b]
    
    ymax=max(SNR_typ_cool[b,0,0:detectors[b]-1,0,1,0],min=ymin)
        
    plot,G[0:detectors[b]-1]+1,SNR_typ_cool[b,0,0:detectors[b]-1,0,1,0],xtit='Detector',ytit='SNR @ T_typ',yrange=[ymin,ymax], $
      xrange=[0,detectors[b]+2],title=title2,charsize=1.2,charthick=5,thick=3,/nodata
    
    oplot,G[0:detectors[b]-1]+1,SNR_typ_cool[b,0,0:detectors[b]-1,0,1,0],symsize=1,color=lcol[0],psym=symbol[0],thick=3

    XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
ENDFOR

FOR b=0, nbands-1 DO BEGIN
    title1='NEdT at T_typ (cool-down)'
    title2=band_name[b]
    
    ymax=max(NEDT_spec[b,0]*1.1)
    ymin=0.0
        
    plot,G[0:detectors[b]-1]+1,NEdT_typ_cool[b,0,0:detectors[b]-1,0,1,0],xtit='Detector',ytit='NEdT @ T_typ',yrange=[ymin,ymax], $
      xrange=[0,detectors[b]+2],title=title2,charsize=1.2,charthick=5,thick=3,/nodata
    
    oplot,G[0:detectors[b]-1]+1,NEdT_typ_cool[b,0,0:detectors[b]-1,0,1,0],symsize=1,color=lcol[0],psym=symbol[0],thick=3
    oplot,[0.,40.],[mean(NEdT_spec[b,0]),mean(NEdT_spec[b,0])],linestyle=2,color=1,thick=5

    XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
ENDFOR
!p.multi=[0,1,2]

; Plot the SNR vs dL_BCS for the weighted function along with the corresponding fitting
; residual on one page.  
E=findgen(1000)
F=findgen(1000)
HAM=['A','B']
SS=[' SS1',' SS2']
FOR b=0, nbands-1 DO BEGIN
    !p.position=0

    FOR is=0, subsets[b]-1 DO BEGIN
        FOR ih=0, nham-1 DO BEGIN
            IF band_type[b] EQ 0 THEN BEGIN
                title1=band_name[b]+': SNR vs dL_BCS (powell); warm-up'
                title2=band_name[b]+', HAM= '+HAM[ih]+' (weighted function)'
            ENDIF
            IF band_type[b] EQ 1 THEN BEGIN
                title1=band_name[b]+SS[is]+': SNR vs dL_BCS (powell); warm-up'
                title2=band_name[b]+SS[is]+', '+'HAM= '+HAM[ih]+' (weighted function)'
            ENDIF
            
            ymax=max(SNR[warm,b,ih,*,is,0])
            
            ; Plot the SNR vs dl_BCS..
            plot,rad_OBC[warm,b,ih,8,is,0]*0.4444,SNR[warm,b,ih,8,is,0],yrange=[0,ymax],xrange=[0,L_max[b,0]], $
              xtit='dL_BCS (Wm-2sr-1um-1)',ytit='SNR',title=title2,charsize=1.2,charthick=5,thick=3,/nodata
                    
            F[*]=0.1*E[*]
            FOR id=0, detectors[b]-1 DO BEGIN
                oplot,rad_OBC[warm,b,ih,id,is,0]*0.4444,SNR[warm,b,ih,id,is,0],symsize=1,color=lcol[id],psym=symbol[id],thick=3
                oplot,F[*],F[*]/sqrt(snr_coeff_warm[b,ih,id,is,0,1,0]+snr_coeff_warm[b,ih,id,is,1,1,0]*F[*]+snr_coeff_warm[b,ih,id,is,2,1,0]*F[*]^2),color=lcol[id],thick=3
            ENDFOR
            oplot,[L_max[b,0],L_max[b,0]],[-100,10000],symsize=1,color=lcol[1],linestyle=2,thick=3
            oplot,[L_typ[b,0],L_typ[b,0]],[-100,10000],symsize=1,color=lcol[2],linestyle=2,thick=3
            oplot,[L_min[b,0],L_min[b,0]],[-100,10000],symsize=1,color=lcol[3],linestyle=2,thick=3

            XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
            IF band_type[b] EQ 1 THEN set_legend,2,chname,lcol,symbol
            IF band_type[b] EQ 0 THEN set_legend,1,chname,lcol,symbol
            
            ; Plot the fitting residual.
            plot,rad_OBC[warm,b,ih,8,is,0]*0.4444,snr_fit_warm[warm,b,ih,8,is,1,0],xtit='dL_BCS (Wm-2sr-1um-1)', $
              ytit='SNR Fitting Residual',xrange=[0,L_max[b,0]],yrange=[-0.5,0.5],title=title2,charsize=1.2,charthick=5,thick=3,/nodata
            
            FOR id=0, detectors[b]-1 DO BEGIN
                oplot,rad_OBC[warm,b,ih,id,is,0]*0.4444,snr_fit_warm[warm,b,ih,id,is,1,0],symsize=1,color=lcol[id],psym=symbol[id],thick=3
                oplot,rad_OBC[warm,b,ih,id,is,0]*0.4444,snr_fit_warm[warm,b,ih,id,is,1,0],color=lcol[id],thick=3
            ENDFOR
            oplot,[L_max[b,0],L_max[b,0]],[-100,10000],symsize=1,color=lcol[1],linestyle=2,thick=3
            oplot,[L_typ[b,0],L_typ[b,0]],[-100,10000],symsize=1,color=lcol[2],linestyle=2,thick=3
            oplot,[L_min[b,0],L_min[b,0]],[-100,10000],symsize=1,color=lcol[3],linestyle=2,thick=3
            
            XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
            IF band_type[b] EQ 1 THEN set_legend,2,chname,lcol,symbol
            IF band_type[b] EQ 0 THEN set_legend,1,chname,lcol,symbol
        ENDFOR
    ENDFOR
ENDFOR

FOR b=0, nbands-1 DO BEGIN
    !p.position=0

    FOR is=0, subsets[b]-1 DO BEGIN
        FOR ih=0, nham-1 DO BEGIN
            IF band_type[b] EQ 0 THEN BEGIN
                title1=band_name[b]+': SNR vs dL_BCS (powell); cool-down'
                title2=band_name[b]+', HAM= '+HAM[ih]+' (weighted function)'
            ENDIF
            IF band_type[b] EQ 1 THEN BEGIN
                title1=band_name[b]+SS[is]+': SNR vs dL_BCS (powell); cool-down'
                title2=band_name[b]+SS[is]+', '+'HAM= '+HAM[ih]+' (weighted function)'
            ENDIF
            
            ymax=max(SNR[cool,b,ih,*,is,0])
            
            ; Plot the SNR vs dl_BCS..
            plot,rad_OBC[cool,b,ih,8,is,0]*0.4444,SNR[cool,b,ih,8,is,0],yrange=[0,ymax],xrange=[0,L_max[b,0]], $
              xtit='dL_BCS (Wm-2sr-1um-1)',ytit='SNR',title=title2,charsize=1.2,charthick=5,thick=3,/nodata
                    
            F[*]=0.1*E[*]
            FOR id=0, detectors[b]-1 DO BEGIN
                oplot,rad_OBC[cool,b,ih,id,is,0]*0.4444,SNR[cool,b,ih,id,is,0],symsize=1,color=lcol[id],psym=symbol[id],thick=3
                oplot,F[*],snr_coeff_cool[b,ih,id,is,0,1,0]+snr_coeff_cool[b,ih,id,is,1,1,0]*F[*]+snr_coeff_cool[b,ih,id,is,2,1,0]*F[*]^2,color=lcol[id],thick=3
            ;    oplot,F[*],F[*]/sqrt(snr_coeff_cool[b,ih,id,is,0,1,0]+snr_coeff_cool[b,ih,id,is,1,1,0]*F[*]+snr_coeff_cool[b,ih,id,is,2,1,0]*F[*]^2),color=lcol[id],thick=3
            ENDFOR
            oplot,[L_max[b,0],L_max[b,0]],[-100,10000],symsize=1,color=lcol[1],linestyle=2,thick=3
            oplot,[L_typ[b,0],L_typ[b,0]],[-100,10000],symsize=1,color=lcol[2],linestyle=2,thick=3
            oplot,[L_min[b,0],L_min[b,0]],[-100,10000],symsize=1,color=lcol[3],linestyle=2,thick=3

            XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
            IF band_type[b] EQ 1 THEN set_legend,2,chname,lcol,symbol
            IF band_type[b] EQ 0 THEN set_legend,1,chname,lcol,symbol
            
            ; Plot the fitting residual.
            plot,rad_OBC[cool,b,ih,8,is,0]*0.4444,snr_fit_cool[cool,b,ih,8,is,1,0],xtit='dL_BCS (Wm-2sr-1um-1)', $
              ytit='SNR Fitting Residual',xrange=[0,L_max[b,0]],yrange=[-0.5,0.5],title=title2,charsize=1.2,charthick=5,thick=3,/nodata
            
            FOR id=0, detectors[b]-1 DO BEGIN
                oplot,rad_OBC[cool,b,ih,id,is,0]*0.4444,snr_fit_cool[cool,b,ih,id,is,1,0],symsize=1,color=lcol[id],psym=symbol[id],thick=3
                oplot,rad_OBC[cool,b,ih,id,is,0]*0.4444,snr_fit_cool[cool,b,ih,id,is,1,0],color=lcol[id],thick=3
            ENDFOR
            oplot,[L_max[b,0],L_max[b,0]],[-100,10000],symsize=1,color=lcol[1],linestyle=2,thick=3
            oplot,[L_typ[b,0],L_typ[b,0]],[-100,10000],symsize=1,color=lcol[2],linestyle=2,thick=3
            oplot,[L_min[b,0],L_min[b,0]],[-100,10000],symsize=1,color=lcol[3],linestyle=2,thick=3
            
            XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
            IF band_type[b] EQ 1 THEN set_legend,2,chname,lcol,symbol
            IF band_type[b] EQ 0 THEN set_legend,1,chname,lcol,symbol
        ENDFOR
    ENDFOR
ENDFOR

device,/close

END
