;*****************************************************************************
;				NICST TOOL
;
;  RC-5 Part 1 test for TEB bands. Calculates the effective EV source radiance
;  and compares to specifications.
;
;  Input:
;  1) Input file with paths to RVS, and general info sav files as well
;     as the .temp.sav, .dn.sav, .rad.sav, .rg.sav, and .snr.sav files.
;
;  Output:
;  1) rad_OBC_ret[collect,bands,HAM,detectors,subsets,fits,rsr]
;  2) mean_ARD_obc[collect,bands,HAM,subsets,fits,rsr]
;  3) max_ARD_obc[collect,bands,HAM,subsets,fits,rsr]
;  4) ARD_obc[collect,bands,HAM,detectors,subsets,fits,rsr]
;  5) RRU_OBC_det[collect,bands,HAM,detectors,subsets,fits,rsr]
;  6) RRU_OBC[collect,bands,HAM,subsets,fits,rsr]
;  7) rad_BCS_ret[collect,bands,HAM,detectors,subsets,fits,rsr]
;  8) mean_ARD[collect,bands,HAM,subsets,fits,rsr]
;  9) max_ARD[collect,bands,HAM,subsets,fits,rsr]
;  10) ARD[collect,bands,HAM,detectors,subsets,fits,rsr]
;  11) RRU_BCS_det[collect,bands,HAM,detectors,subsets,fits,rsr]
;  12) RRU_BCS[collect,bands,HAM,subsets,fits,rsr]
;  
;  v1.0 - 06/27/2008 - Jeff McIntire
;  v2.0 - 03/30/2009 - Jeff McIntire
;    -- added BCS ARD and plotting routines
;*****************************************************************************

PRO RC5_OBC_eff_rad, infile

;*****************************************************************************
;  Read in input file and sav TEB file.
;*****************************************************************************

nlines=File_Lines(infile)
ab=''
header=strarr(1)
inpath=strarr(1)		; Input path.
outpath=strarr(1)		; Output path.
rvs_in=strarr(1)		; RVS .sav file.
param_in=strarr(1)		; EDU coeff .sav file.
rsrpath=strarr(1)		; RSR .sav file.
maxscan=intarr(1)               ; # of scans

openr,lun,infile,/Get_Lun	
readf,lun,header	
readf,lun,inpath
readf,lun,outpath
readf,lun,rvs_in
readf,lun,param_in
readf,lun,rsrpath
readf,lun,maxscan
Free_Lun,lun

max_scan=maxscan[0]

a2=strsplit(outpath,'/',/Extract)
a3=N_ELEMENTS(a2)

restore,'general.TEB.2.sav'
restore,outpath+a2[a3-3]+'.'+a2[a3-2]+'.BCS.rg.sav'
restore,outpath+a2[a3-3]+'.'+a2[a3-2]+'.'+a2[a3-1]+'.dn.sav'
restore,outpath+a2[a3-3]+'.'+a2[a3-2]+'.'+a2[a3-1]+'.rad.sav'
restore,outpath+a2[a3-3]+'.'+a2[a3-2]+'.'+a2[a3-1]+'.temp.sav'

outfile=outpath+a2[a3-3]+'.'+a2[a3-2]+'.'+a2[a3-1]+'.eff_rad.sav'

;*****************************************************************************
;  Find warm-up and cool-down collects.
;*****************************************************************************

F=findgen(ncollects)
FOR ih=0, nham-1 DO BEGIN
    max_col=WHERE(T_obc[ih,*] EQ max(T_obc[ih,*]))
    warm=WHERE(F[0:ncollects-1] LE max_col[0])
    cool=WHERE(F[0:ncollects-1] GT max_col[0])
ENDFOR

;*****************************************************************************
;  Reform the dn and radiance to get rid of extra zeros (use the OBC radiance 
;  to get the right indices for the BCS radiance).
;*****************************************************************************

dn_x=dblarr(ncollects,nbands,nham,maxdet,maxsubsets,max_scan/2)
dn_y=dblarr(ncollects,nbands,nham,maxdet,maxsubsets,max_scan/2)
rad_p3_x=dblarr(ncollects,nbands,nham,maxdet,max_scan/2,5,2)
rad_BCS_scan_x=dblarr(ncollects,nbands,nham,maxdet,maxsubsets,max_scan/2,2)
rad_OBC_scan_x=dblarr(ncollects,nbands,nham,maxdet,maxsubsets,max_scan/2,2)
rad_OBC_1_scan_x=dblarr(ncollects,nbands,nham,maxdet,maxsubsets,max_scan/2,2)

FOR rsr=0, 1 DO BEGIN
    FOR b=0, nbands-1 DO BEGIN
        FOR is=0, subsets[b]-1 DO BEGIN
            FOR ih=0, nham-1 DO BEGIN
                FOR id=0, detectors[b]-1 DO BEGIN
                    FOR col=0, ncollects-1 DO BEGIN
                        index1=WHERE(dn_col[col,b,ih,id,is,1,*,0] NE 0., arr1)
                        index2=WHERE(dn_col[col,b,ih,id,is,1,*,2] NE 0, arr2)
                        index3=WHERE(abs(rad_p3[col,b,ih,id,*,0,rsr]) NE 0, arr3)
                        index4=WHERE(abs(rad_p3[col,b,ih,id,*,1,rsr]) NE 0, arr4)
                        index5=WHERE(abs(rad_p3[col,b,ih,id,*,4,rsr]) NE 0, arr5)
                        index6=WHERE(abs(rad_BCS_scan[col,b,ih,id,is,*,rsr]) NE 0, arr6)
                        index7=WHERE(abs(rad_OBC_scan[col,b,ih,id,is,*,rsr]) NE 0, arr7)
                        index8=WHERE(abs(rad_OBC_1_scan[col,b,ih,id,is,*,rsr]) NE 0, arr8)
                        dn_x[col,b,ih,id,is,0:49]=dn_col[col,b,ih,id,is,1,index1,0]
                        dn_y[col,b,ih,id,is,0:49]=dn_col[col,b,ih,id,is,1,index2,2]
                        rad_p3_x[col,b,ih,id,0:49,0,rsr]=rad_p3[col,b,ih,id,index3,0,rsr]
                        rad_p3_x[col,b,ih,id,0:49,1,rsr]=rad_p3[col,b,ih,id,index4,1,rsr]
                        rad_p3_x[col,b,ih,id,0:49,4,rsr]=rad_p3[col,b,ih,id,index5,4,rsr]
                        rad_BCS_scan_x[col,b,ih,id,is,0:49,rsr]=rad_BCS_scan[col,b,ih,id,is,index6,rsr]
                        rad_OBC_scan_x[col,b,ih,id,is,0:49,rsr]=rad_OBC_scan[col,b,ih,id,is,index7,rsr]
                        rad_OBC_1_scan_x[col,b,ih,id,is,0:49,rsr]=rad_OBC_1_scan[col,b,ih,id,is,index8,rsr]
                    ENDFOR
                ENDFOR
            ENDFOR
        ENDFOR
    ENDFOR
ENDFOR

;*****************************************************************************
;  Find retrived OBC and BCS radiances for RC5 part 2.
;*****************************************************************************

mindet=[0,0,0,0,1,0,0,0]

NEDT_spec=[[2.5,1.5,0.396,0.107,0.091,0.07,0.072,0.072],[0,0,0,0.423,0,0,0,0]]

rad_OBC_1_x=dblarr(ncollects,nbands,nham,maxdet,maxsubsets,2)
rad_OBC_ret_2=dblarr(ncollects,nbands,nham,maxdet,maxsubsets,max_scan/2,3,2)
rad_BCS_ret_2=dblarr(ncollects,nbands,nham,maxdet,maxsubsets,max_scan/2,3,2)
rad_OBC_ret=dblarr(ncollects,nbands,nham,maxdet,maxsubsets,3,2)
rad_BCS_ret=dblarr(ncollects,nbands,nham,maxdet,maxsubsets,3,2)
delta_rad_OBC_ret=dblarr(ncollects,nbands,nham,maxdet,maxsubsets,3,2)
delta_rad_BCS_ret=dblarr(ncollects,nbands,nham,maxdet,maxsubsets,3,2)

ARD_obc=dblarr(ncollects,nbands,nham,maxdet,maxsubsets,3,2)
ARD=dblarr(ncollects,nbands,nham,maxdet,maxsubsets,3,2)
mean_ARD_obc=dblarr(ncollects,nbands,nham,maxsubsets,3,2)
mean_ARD=dblarr(ncollects,nbands,nham,maxsubsets,3,2)
max_ARD_obc=dblarr(ncollects,nbands,nham,maxsubsets,3,2)
max_ARD=dblarr(ncollects,nbands,nham,maxsubsets,3,2)

RRU_OBC_det=dblarr(ncollects,nbands,nham,maxdet,maxsubsets,3,2)
RRU_BCS_det=dblarr(ncollects,nbands,nham,maxdet,maxsubsets,3,2)
RRU_OBC=dblarr(ncollects,nbands,nham,maxsubsets,3,2)
RRU_BCS=dblarr(ncollects,nbands,nham,maxsubsets,3,2)

FOR col=0, ncollects-1 DO BEGIN
    FOR rsr=0, 1 DO BEGIN
        FOR b=0, nbands-1 DO BEGIN
            FOR ih=0, nham-1 DO BEGIN
                FOR is=0, subsets[b]-1 DO BEGIN
                    FOR id=0, detectors[b]-1 DO BEGIN
                        FOR iscan=0, max_scan/2-1 DO BEGIN

                            ; Select the matching subsample for the OBC dn.
                            IF dn_y[col,b,ih,id,0,iscan] GT dn_y[col,b,ih,id,1,iscan] AND dn_x[col,b,ih,id,0,iscan] GT dn_x[col,b,ih,id,1,iscan] THEN BEGIN isubset=is
                            ENDIF ELSE BEGIN
                                IF is EQ 0 THEN isubset=1
                                IF is EQ 1 THEN isubset=0
                            ENDELSE

;*****************************************************************************
;  Calculate retrived OBC and BCS radiances.
;*****************************************************************************

                            ; Linear fit.
                            rad_OBC_ret_2[col,b,ih,id,is,iscan,0,rsr] $
                              =(rg_1[b,ih,id,is,0,1,rsr]+rg_1[b,ih,id,is,1,1,rsr]*dn_y[col,b,ih,id,isubset,iscan])/p[b] $
                              *(rad_BCS_scan_x[col,b,ih,id,is,iscan,rsr]/(rg_1[b,ih,id,is,0,1,rsr] $
                                                                          +rg_1[b,ih,id,is,1,1,rsr]*dn_x[col,b,ih,id,is,iscan])) $
                              +rvs[b,is,id,ih,1]*rad_p1[col,b,id,1,rsr]-(rvs[b,is,id,ih,1]-1.)/p[b] $
                              *(rad_p3_x[col,b,ih,id,iscan,0,rsr]-(1-p[b])*rad_p3_x[col,b,ih,id,iscan,1,rsr])
                            rad_BCS_ret_2[col,b,ih,id,is,iscan,0,rsr] $
                              =(rg_1[b,ih,id,is,0,1,rsr]+rg_1[b,ih,id,is,1,1,rsr]*dn_x[col,b,ih,id,is,iscan])/(rvs[b,is,id,ih,0]*p[b]) $
                              *(rad_OBC_scan_x[col,b,ih,id,is,iscan,rsr]/(rg_1[b,ih,id,is,0,1,rsr] $
                                                                          +rg_1[b,ih,id,is,1,1,rsr]*dn_y[col,b,ih,id,isubset,iscan])) $
                              +rvs[b,is,id,ih,1]/rvs[b,is,id,ih,0]*rad_p1[col,b,id,1,rsr]-(rvs[b,is,id,ih,1]-rvs[b,is,id,ih,0])/(rvs[b,is,id,ih,0]*p[b]) $
                              *(rad_p3_x[col,b,ih,id,iscan,0,rsr]-(1-p[b])*rad_p3_x[col,b,ih,id,iscan,1,rsr])

                            ; Quadratic fit.
                            rad_OBC_ret_2[col,b,ih,id,is,iscan,1,rsr] $
                              =(rg_1[b,ih,id,is,0,1,rsr]+rg_1[b,ih,id,is,1,1,rsr]*dn_y[col,b,ih,id,isubset,iscan] $
                                +rg_1[b,ih,id,is,2,1,rsr]*dn_y[col,b,ih,id,isubset,iscan]^2)/p[b] $
                              *(rad_BCS_scan_x[col,b,ih,id,is,iscan,rsr]/(rg_1[b,ih,id,is,0,1,rsr] $
                                                                          +rg_1[b,ih,id,is,1,1,rsr]*dn_x[col,b,ih,id,is,iscan] $
                                                                          +rg_1[b,ih,id,is,2,1,rsr]*dn_x[col,b,ih,id,is,iscan]^2)) $
                              +rvs[b,is,id,ih,1]*rad_p1[col,b,id,1,rsr]-(rvs[b,is,id,ih,1]-1.)/p[b] $
                              *(rad_p3_x[col,b,ih,id,iscan,0,rsr]-(1-p[b])*rad_p3_x[col,b,ih,id,iscan,1,rsr])
                            rad_BCS_ret_2[col,b,ih,id,is,iscan,1,rsr] $
                              =(rg_1[b,ih,id,is,0,1,rsr]+rg_1[b,ih,id,is,1,1,rsr]*dn_x[col,b,ih,id,is,iscan] $
                                +rg_1[b,ih,id,is,2,1,rsr]*dn_x[col,b,ih,id,is,iscan]^2)/(rvs[b,is,id,ih,0]*p[b]) $
                              *(rad_OBC_scan_x[col,b,ih,id,is,iscan,rsr]/(rg_1[b,ih,id,is,0,1,rsr] $
                                                                          +rg_1[b,ih,id,is,1,1,rsr]*dn_y[col,b,ih,id,isubset,iscan] $
                                                                          +rg_1[b,ih,id,is,2,1,rsr]*dn_y[col,b,ih,id,isubset,iscan]^2)) $
                              +rvs[b,is,id,ih,1]/rvs[b,is,id,ih,0]*rad_p1[col,b,id,1,rsr]-(rvs[b,is,id,ih,1]-rvs[b,is,id,ih,0])/(rvs[b,is,id,ih,0]*p[b]) $
                              *(rad_p3_x[col,b,ih,id,iscan,0,rsr]-(1-p[b])*rad_p3_x[col,b,ih,id,iscan,1,rsr])

                            ; Cubic fit.
                            rad_OBC_ret_2[col,b,ih,id,is,iscan,2,rsr] $
                              =(rg_1[b,ih,id,is,0,1,rsr]+rg_1[b,ih,id,is,1,1,rsr]*dn_y[col,b,ih,id,isubset,iscan] $
                                +rg_1[b,ih,id,is,2,1,rsr]*dn_y[col,b,ih,id,isubset,iscan]^2 $
                                +rg_1[b,ih,id,is,3,1,rsr]*dn_y[col,b,ih,id,isubset,iscan]^3)/p[b] $
                              *(rad_BCS_scan_x[col,b,ih,id,is,iscan,rsr]/(rg_1[b,ih,id,is,0,1,rsr] $
                                                                          +rg_1[b,ih,id,is,1,1,rsr]*dn_x[col,b,ih,id,is,iscan] $
                                                                          +rg_1[b,ih,id,is,2,1,rsr]*dn_x[col,b,ih,id,is,iscan]^2 $
                                                                          +rg_1[b,ih,id,is,3,1,rsr]*dn_x[col,b,ih,id,is,iscan]^3)) $
                              +rvs[b,is,id,ih,1]*rad_p1[col,b,id,1,rsr]-(rvs[b,is,id,ih,1]-1.)/p[b] $
                              *(rad_p3_x[col,b,ih,id,iscan,0,rsr]-(1-p[b])*rad_p3_x[col,b,ih,id,iscan,1,rsr])
                            rad_BCS_ret_2[col,b,ih,id,is,iscan,2,rsr] $
                              =(rg_1[b,ih,id,is,0,1,rsr]+rg_1[b,ih,id,is,1,1,rsr]*dn_x[col,b,ih,id,is,iscan] $
                                +rg_1[b,ih,id,is,2,1,rsr]*dn_x[col,b,ih,id,is,iscan]^2 $
                                +rg_1[b,ih,id,is,3,1,rsr]*dn_x[col,b,ih,id,is,iscan]^3)/(rvs[b,is,id,ih,0]*p[b]) $
                              *(rad_OBC_scan_x[col,b,ih,id,is,iscan,rsr]/(rg_1[b,ih,id,is,0,1,rsr] $
                                                                          +rg_1[b,ih,id,is,1,1,rsr]*dn_y[col,b,ih,id,isubset,iscan] $
                                                                          +rg_1[b,ih,id,is,2,1,rsr]*dn_y[col,b,ih,id,isubset,iscan]^2 $
                                                                          +rg_1[b,ih,id,is,3,1,rsr]*dn_y[col,b,ih,id,isubset,iscan]^3)) $
                              +rvs[b,is,id,ih,1]/rvs[b,is,id,ih,0]*rad_p1[col,b,id,1,rsr]-(rvs[b,is,id,ih,1]-rvs[b,is,id,ih,0])/(rvs[b,is,id,ih,0]*p[b]) $
                              *(rad_p3_x[col,b,ih,id,iscan,0,rsr]-(1-p[b])*rad_p3_x[col,b,ih,id,iscan,1,rsr])
                        ENDFOR

;*****************************************************************************
;  Calculate the OBC and BCS ARD, find the mean and the max..
;*****************************************************************************

                        rad_OBC_1_x[col,b,ih,id,is,rsr]=mean(rad_OBC_1_scan_x[col,b,ih,id,is,0:max_scan/2-1,rsr])

                        rad_OBC_ret[col,b,ih,id,is,0,rsr]=mean(rad_OBC_ret_2[col,b,ih,id,is,0:max_scan/2-1,0,rsr])
                        rad_OBC_ret[col,b,ih,id,is,1,rsr]=mean(rad_OBC_ret_2[col,b,ih,id,is,0:max_scan/2-1,1,rsr])
                        rad_OBC_ret[col,b,ih,id,is,2,rsr]=mean(rad_OBC_ret_2[col,b,ih,id,is,0:max_scan/2-1,2,rsr])

                        rad_BCS_ret[col,b,ih,id,is,0,rsr]=mean(rad_BCS_ret_2[col,b,ih,id,is,0:max_scan/2-1,0,rsr])
                        rad_BCS_ret[col,b,ih,id,is,1,rsr]=mean(rad_BCS_ret_2[col,b,ih,id,is,0:max_scan/2-1,1,rsr])
                        rad_BCS_ret[col,b,ih,id,is,2,rsr]=mean(rad_BCS_ret_2[col,b,ih,id,is,0:max_scan/2-1,2,rsr])

                        ARD_obc[col,b,ih,id,is,0:2,rsr]=-100.*(rad_OBC_ret[col,b,ih,id,is,0:2,rsr]/rad_OBC_1_x[col,b,ih,id,is,rsr]-1.)
                        ARD[col,b,ih,id,is,0:2,rsr]=100.*(rad_BCS_ret[col,b,ih,id,is,0:2,rsr]/rad_p1[col,b,id,0,rsr]-1.)

                        mean_ARD_obc[col,b,ih,is,0,rsr]=mean(ARD_obc[col,b,ih,mindet[b]:detectors[b]-1,is,0,rsr])
                        mean_ARD_obc[col,b,ih,is,1,rsr]=mean(ARD_obc[col,b,ih,mindet[b]:detectors[b]-1,is,1,rsr])
                        mean_ARD_obc[col,b,ih,is,2,rsr]=mean(ARD_obc[col,b,ih,mindet[b]:detectors[b]-1,is,2,rsr])
                        mean_ARD[col,b,ih,is,0,rsr]=mean(ARD[col,b,ih,mindet[b]:detectors[b]-1,is,0,rsr])
                        mean_ARD[col,b,ih,is,1,rsr]=mean(ARD[col,b,ih,mindet[b]:detectors[b]-1,is,1,rsr])
                        mean_ARD[col,b,ih,is,2,rsr]=mean(ARD[col,b,ih,mindet[b]:detectors[b]-1,is,2,rsr])

                        max_ARD_obc[col,b,ih,is,0,rsr]=max(ARD_obc[col,b,ih,mindet[b]:detectors[b]-1,is,0,rsr])
                        max_ARD_obc[col,b,ih,is,1,rsr]=max(ARD_obc[col,b,ih,mindet[b]:detectors[b]-1,is,1,rsr])
                        max_ARD_obc[col,b,ih,is,2,rsr]=max(ARD_obc[col,b,ih,mindet[b]:detectors[b]-1,is,2,rsr])
                        max_ARD[col,b,ih,is,0,rsr]=max(ARD_obc[col,b,ih,mindet[b]:detectors[b]-1,is,0,rsr])
                        max_ARD[col,b,ih,is,1,rsr]=max(ARD_obc[col,b,ih,mindet[b]:detectors[b]-1,is,1,rsr])
                        max_ARD[col,b,ih,is,2,rsr]=max(ARD_obc[col,b,ih,mindet[b]:detectors[b]-1,is,2,rsr])

;*****************************************************************************
;  Calculate the OBC and BCS ARD, find the mean and the max..
;*****************************************************************************

                        delta_rad_OBC_ret[col,b,ih,id,is,0:2,rsr]=rad_OBC_ret[col,b,ih,id,is,0:2,rsr]-rad_OBC_1_x[col,b,ih,id,is,rsr]
                        delta_rad_BCS_ret[col,b,ih,id,is,0:2,rsr]=rad_BCS_ret[col,b,ih,id,is,0:2,rsr]-rad_p1[col,b,id,0,rsr]

                    ENDFOR
                    FOR id=0, detectors[b]-1 DO BEGIN

                        RRU_OBC_det[col,b,ih,id,is,0,rsr]=0.4444*abs(delta_rad_OBC_ret[col,b,ih,id,is,0,rsr] $
                                                                     -mean(delta_rad_OBC_ret[col,b,ih,mindet[b]:detectors[b]-1,is,0,rsr])) $
                          /(NEDT_spec[b,0]*Planck_deriv(T_typ[b,0],lambda_center[b]))
                        RRU_OBC_det[col,b,ih,id,is,1,rsr]=0.4444*abs(delta_rad_OBC_ret[col,b,ih,id,is,1,rsr] $
                                                                     -mean(delta_rad_OBC_ret[col,b,ih,mindet[b]:detectors[b]-1,is,1,rsr])) $
                          /(NEDT_spec[b,0]*Planck_deriv(T_typ[b,0],lambda_center[b]))
                        RRU_OBC_det[col,b,ih,id,is,2,rsr]=0.4444*abs(delta_rad_OBC_ret[col,b,ih,id,is,2,rsr] $
                                                                     -mean(delta_rad_OBC_ret[col,b,ih,mindet[b]:detectors[b]-1,is,2,rsr])) $
                          /(NEDT_spec[b,0]*Planck_deriv(T_typ[b,0],lambda_center[b]))
                        RRU_BCS_det[col,b,ih,id,is,0,rsr]=0.4444*abs(delta_rad_BCS_ret[col,b,ih,id,is,0,rsr] $
                                                                     -mean(delta_rad_BCS_ret[col,b,ih,mindet[b]:detectors[b]-1,is,0,rsr])) $
                          /(NEDT_spec[b,0]*Planck_deriv(T_typ[b,0],lambda_center[b]))
                        RRU_BCS_det[col,b,ih,id,is,1,rsr]=0.4444*abs(delta_rad_BCS_ret[col,b,ih,id,is,1,rsr] $
                                                                     -mean(delta_rad_BCS_ret[col,b,ih,mindet[b]:detectors[b]-1,is,1,rsr])) $
                          /(NEDT_spec[b,0]*Planck_deriv(T_typ[b,0],lambda_center[b]))
                        RRU_BCS_det[col,b,ih,id,is,2,rsr]=0.4444*abs(delta_rad_BCS_ret[col,b,ih,id,is,2,rsr] $
                                                                     -mean(delta_rad_BCS_ret[col,b,ih,mindet[b]:detectors[b]-1,is,2,rsr])) $
                          /(NEDT_spec[b,0]*Planck_deriv(T_typ[b,0],lambda_center[b]))

                        RRU_OBC[col,b,ih,is,0,rsr]=max(RRU_OBC_det[col,b,ih,mindet[b]:detectors[b]-1,is,0,rsr])
                        RRU_OBC[col,b,ih,is,1,rsr]=max(RRU_OBC_det[col,b,ih,mindet[b]:detectors[b]-1,is,1,rsr])
                        RRU_OBC[col,b,ih,is,2,rsr]=max(RRU_OBC_det[col,b,ih,mindet[b]:detectors[b]-1,is,2,rsr])
                        RRU_BCS[col,b,ih,is,0,rsr]=max(RRU_BCS_det[col,b,ih,mindet[b]:detectors[b]-1,is,0,rsr])
                        RRU_BCS[col,b,ih,is,1,rsr]=max(RRU_BCS_det[col,b,ih,mindet[b]:detectors[b]-1,is,1,rsr])
                        RRU_BCS[col,b,ih,is,2,rsr]=max(RRU_BCS_det[col,b,ih,mindet[b]:detectors[b]-1,is,2,rsr])
                    ENDFOR
                ENDFOR
            ENDFOR
        ENDFOR
    ENDFOR
ENDFOR

save,/compress,rad_OBC_ret,mean_ARD_obc,max_ARD_obc,ARD_obc,RRU_OBC_det,RRU_OBC,rad_BCS_ret,mean_ARD,max_ARD,ARD,RRU_BCS_det,RRU_BCS,filename=outfile

;*****************************************************************************
;  Save data on ARD to dat file.
;*****************************************************************************

outfile1=outpath+a2[a3-3]+'.'+a2[a3-2]+'.'+a2[a3-1]+'.ard_obc_warm.txt'
outfile2=outpath+a2[a3-3]+'.'+a2[a3-2]+'.'+a2[a3-1]+'.ard_bcs_warm.txt'
outfile3=outpath+a2[a3-3]+'.'+a2[a3-2]+'.'+a2[a3-1]+'.rru_obc_warm.txt'
outfile4=outpath+a2[a3-3]+'.'+a2[a3-2]+'.'+a2[a3-1]+'.rru_bcs_warm.txt'
outfile5=outpath+a2[a3-3]+'.'+a2[a3-2]+'.'+a2[a3-1]+'.ard_obc_cool.txt'
outfile6=outpath+a2[a3-3]+'.'+a2[a3-2]+'.'+a2[a3-1]+'.ard_bcs_cool.txt'
outfile7=outpath+a2[a3-3]+'.'+a2[a3-2]+'.'+a2[a3-1]+'.rru_obc_cool.txt'
outfile8=outpath+a2[a3-3]+'.'+a2[a3-2]+'.'+a2[a3-1]+'.rru_bcs_cool.txt'

fmt_1='(i2, 5x, i3, 5x, i2, 5x, f, 5x, f, 5x, f, 5x, f, 5x, f, 5x, f, 5x, f, 5x, f)'

openw,lun,outfile1,/get_lun
printf,lun,'Warm-up OBC Absolute Radiance Difference (OBC ARD) (quadratic fit)'
printf,lun,'Collect     Temp       HAM      I4        I5       M12       M13        M14      M15      M16A      M16B'
FOR ih=0, nham-1 DO BEGIN
	FOR col=0, ncollects-1 DO BEGIN
            IF col GT max_col[0] THEN continue
		printf,lun,format=fmt_1,col,T_obc[ih,col],ih,mean(mean_ARD_obc[col,0,ih,*,1,0]),mean(mean_ARD_obc[col,1,ih,*,1,0]), $
			mean_ARD_obc[col,2,ih,0,1,0],mean_ARD_obc[col,3,ih,0,1,0],mean_ARD_obc[col,4,ih,0,1,0], $
			mean_ARD_obc[col,5,ih,0,1,0],mean_ARD_obc[col,6,ih,0,1,0],mean_ARD_obc[col,7,ih,0,1,0]
	ENDFOR
ENDFOR
free_lun,lun
openw,lun,outfile2,/get_lun
printf,lun,'Warm-up BCS Absolute Radiance Difference (BCS ARD) (quadratic fit)'
printf,lun,'Collect     Temp       HAM      I4        I5       M12       M13        M14      M15      M16A      M16B'
FOR ih=0, nham-1 DO BEGIN
	FOR col=0, ncollects-1 DO BEGIN
            IF col GT max_col[0] THEN continue
		printf,lun,format=fmt_1,col,T_obc[ih,col],ih,mean(mean_ARD[col,0,ih,*,1,0]),mean(mean_ARD[col,1,ih,*,1,0]), $
			mean_ARD[col,2,ih,0,1,0],mean_ARD[col,3,ih,0,1,0],mean_ARD[col,4,ih,0,1,0], $
			mean_ARD[col,5,ih,0,1,0],mean_ARD[col,6,ih,0,1,0],mean_ARD[col,7,ih,0,1,0]
	ENDFOR
ENDFOR
free_lun,lun
openw,lun,outfile3,/get_lun
printf,lun,'Warm-up OBC Relative Response Uniformity (RRU) (quadratic fit)'
printf,lun,'Collect     Temp       HAM      I4        I5       M12       M13        M14      M15      M16A      M16B'
FOR ih=0, nham-1 DO BEGIN
	FOR col=0, ncollects-1 DO BEGIN
            IF col GT max_col[0] THEN continue
		printf,lun,format=fmt_1,col,T_obc[ih,col],ih,mean(RRU_OBC[col,0,ih,*,1,0]),mean(RRU_OBC[col,1,ih,*,1,0]), $
			RRU_OBC[col,2,ih,0,1,0],RRU_OBC[col,3,ih,0,1,0],RRU_OBC[col,4,ih,0,1,0], $
			RRU_OBC[col,5,ih,0,1,0],RRU_OBC[col,6,ih,0,1,0],RRU_OBC[col,7,ih,0,1,0]
	ENDFOR
ENDFOR
free_lun,lun
openw,lun,outfile4,/get_lun
printf,lun,'Warm-up BCS Relative Response Uniformity (RRU) (quadratic fit)'
printf,lun,'Collect     Temp       HAM      I4        I5       M12       M13        M14      M15      M16A      M16B'
FOR ih=0, nham-1 DO BEGIN
	FOR col=0, ncollects-1 DO BEGIN
            IF col GT max_col[0] THEN continue
		printf,lun,format=fmt_1,col,T_obc[ih,col],ih,mean(RRU_BCS[col,0,ih,*,1,0]),mean(RRU_BCS[col,1,ih,*,1,0]), $
			RRU_BCS[col,2,ih,0,1,0],RRU_BCS[col,3,ih,0,1,0],RRU_BCS[col,4,ih,0,1,0], $
			RRU_BCS[col,5,ih,0,1,0],RRU_BCS[col,6,ih,0,1,0],RRU_BCS[col,7,ih,0,1,0]
	ENDFOR
ENDFOR
free_lun,lun

openw,lun,outfile5,/get_lun
printf,lun,'Cool-down OBC Absolute Radiance Difference (OBC ARD) (quadratic fit)'
printf,lun,'Collect     Temp       HAM      I4        I5       M12       M13        M14      M15      M16A      M16B'
FOR ih=0, nham-1 DO BEGIN
	FOR col=0, ncollects-1 DO BEGIN
            IF col LE max_col[0] THEN continue
            IF col EQ ncollects-1 THEN continue
		printf,lun,format=fmt_1,col,T_obc[ih,col],ih,mean(mean_ARD_obc[col,0,ih,*,1,0]),mean(mean_ARD_obc[col,1,ih,*,1,0]), $
			mean_ARD_obc[col,2,ih,0,1,0],mean_ARD_obc[col,3,ih,0,1,0],mean_ARD_obc[col,4,ih,0,1,0], $
			mean_ARD_obc[col,5,ih,0,1,0],mean_ARD_obc[col,6,ih,0,1,0],mean_ARD_obc[col,7,ih,0,1,0]
	ENDFOR
ENDFOR
free_lun,lun

openw,lun,outfile6,/get_lun
printf,lun,'Cool-down BCS Absolute Radiance Difference (BCS ARD) (quadratic fit)'
printf,lun,'Collect     Temp       HAM      I4        I5       M12       M13        M14      M15      M16A      M16B'
FOR ih=0, nham-1 DO BEGIN
	FOR col=0, ncollects-1 DO BEGIN
            IF col LE max_col[0] THEN continue
            IF col EQ ncollects-1 THEN continue
		printf,lun,format=fmt_1,col,T_obc[ih,col],ih,mean(mean_ARD[col,0,ih,*,1,0]),mean(mean_ARD[col,1,ih,*,1,0]), $
			mean_ARD[col,2,ih,0,1,0],mean_ARD[col,3,ih,0,1,0],mean_ARD[col,4,ih,0,1,0], $
			mean_ARD[col,5,ih,0,1,0],mean_ARD[col,6,ih,0,1,0],mean_ARD[col,7,ih,0,1,0]
	ENDFOR
ENDFOR
free_lun,lun

openw,lun,outfile7,/get_lun
printf,lun,'Cool-down OBC Relative Response Uniformity (RRU) (quadratic fit)'
printf,lun,'Collect     Temp       HAM      I4        I5       M12       M13        M14      M15      M16A      M16B'
FOR ih=0, nham-1 DO BEGIN
	FOR col=0, ncollects-1 DO BEGIN
            IF col LE max_col[0] THEN continue
            IF col EQ ncollects-1 THEN continue
		printf,lun,format=fmt_1,col,T_obc[ih,col],ih,mean(RRU_OBC[col,0,ih,*,1,0]),mean(RRU_OBC[col,1,ih,*,1,0]), $
			RRU_OBC[col,2,ih,0,1,0],RRU_OBC[col,3,ih,0,1,0],RRU_OBC[col,4,ih,0,1,0], $
			RRU_OBC[col,5,ih,0,1,0],RRU_OBC[col,6,ih,0,1,0],RRU_OBC[col,7,ih,0,1,0]
	ENDFOR
ENDFOR
free_lun,lun

openw,lun,outfile8,/get_lun
printf,lun,'Cool-down BCS Relative Response Uniformity (RRU) (quadratic fit)'
printf,lun,'Collect     Temp       HAM      I4        I5       M12       M13        M14      M15      M16A      M16B'
FOR ih=0, nham-1 DO BEGIN
	FOR col=0, ncollects-1 DO BEGIN
            IF col LE max_col[0] THEN continue
            IF col EQ ncollects-1 THEN continue
		printf,lun,format=fmt_1,col,T_obc[ih,col],ih,mean(RRU_BCS[col,0,ih,*,1,0]),mean(RRU_BCS[col,1,ih,*,1,0]), $
			RRU_BCS[col,2,ih,0,1,0],RRU_BCS[col,3,ih,0,1,0],RRU_BCS[col,4,ih,0,1,0], $
			RRU_BCS[col,5,ih,0,1,0],RRU_BCS[col,6,ih,0,1,0],RRU_BCS[col,7,ih,0,1,0]
	ENDFOR
ENDFOR
free_lun,lun
close,lun,/file,/all

;*****************************************************************************
;  Plot the BCS ARD in a .ps file.
;*****************************************************************************

set_multicolor,xsave,ysave,psave,chname,lcol,symbol,red,green,blue
set_plot,'ps'
outfname=outpath+a2[a3-3]+'.'+a2[a3-2]+'.'+a2[a3-1]+'.ard.bcs.ps'
device,/landscape,filename=outfname,/color
!p.multi=[0,1,1]
!p.position=0

;*****************************************************************************
;  Plot the ARD per detector for warm-up.
;*****************************************************************************

G=findgen(30)
title1='BCS Absolute Radiance Difference, (SRV0545-6)'
FOR b=0, nbands-1 DO BEGIN
    title2=band_name[b]+' Warm-up, HAM A (quadratic poly_fit)'

    ymax=max(ARD[0:max_col[0],b,0,mindet[b]:detectors[b]-1,0,1,0],min=ymin)

    plot,T_obc[0,0:max_col[0]],ARD[0:max_col[0],b,0,0,0,1,0],xtit='OBC Temperature (K)',ytit='BCS ARD',yrange=[ymin,ymax], $
      xrange=[260,320],title=title2,charsize=1.2,charthick=5,/nodata

    FOR id=0,detectors[b]-1 DO BEGIN
        oplot,T_obc[0,0:max_col[0]],ARD[0:max_col[0],b,0,id,0,1,0],symsize=1,color=lcol[id],psym=symbol[id]
        oplot,T_obc[0,0:max_col[0]],ARD[0:max_col[0],b,0,id,0,1,0],color=lcol[id]
    ENDFOR
    XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
    IF band_type[b] EQ 0 THEN set_legend,1,chname,lcol,symbol
    IF band_type[b] EQ 1 THEN set_legend,2,chname,lcol,symbol
ENDFOR

;*****************************************************************************
;  Plot the ARD per detector for cool-down.
;*****************************************************************************

G=findgen(30)
title1='BCS Absolute Radiance Difference, (SRV0545-6)'
FOR b=0, nbands-1 DO BEGIN
    title2=band_name[b]+' Cool-down, HAM A (quadratic poly_fit)'

    ymax=max(ARD[max_col[0]+1:ncollects-1,b,0,mindet[b]:detectors[b]-1,0,1,0],min=ymin)

    plot,T_obc[0,max_col[0]+1:ncollects-1],ARD[max_col[0]+1:ncollects-1,b,0,0,0,1,0],xtit='OBC Temperature (K)',ytit='BCS ARD',yrange=[ymin,ymax], $
      xrange=[260,320],title=title2,charsize=1.2,charthick=5,/nodata

    FOR id=0,detectors[b]-1 DO BEGIN
        oplot,T_obc[0,max_col[0]+1:ncollects-1],ARD[max_col[0]+1:ncollects-1,b,0,id,0,1,0],symsize=1,color=lcol[id],psym=symbol[id]
        oplot,T_obc[0,max_col[0]+1:ncollects-1],ARD[max_col[0]+1:ncollects-1,b,0,id,0,1,0],color=lcol[id]
    ENDFOR
    XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
    IF band_type[b] EQ 0 THEN set_legend,1,chname,lcol,symbol
    IF band_type[b] EQ 1 THEN set_legend,2,chname,lcol,symbol
ENDFOR

;*****************************************************************************
;  Plot the mean ARD for warm-up and cool-down separately and together.
;*****************************************************************************

ymax=max(mean_ARD[0:max_col[0],0:nbands-1,0,0,1,0],min=ymin)

title1='Warm-up BCS Absolute Radiance Difference, (SRV0545-6)'
plot,T_obc[0,0:max_col[0]],mean_ARD[0:max_col[0],0,0,0,1,0],xtit='OBC Temperature (K)',ytit='BCS ARD',yrange=[ymin,ymax], $
  xrange=[260,320],charsize=1.2,charthick=5,/nodata
FOR b=0, nbands-1 DO BEGIN
    oplot,T_obc[0,0:max_col[0]],mean_ARD[0:max_col[0],b,0,0,1,0],symsize=1,color=lcol[b],psym=symbol[b]
    oplot,T_obc[0,0:max_col[0]],mean_ARD[0:max_col[0],b,0,0,1,0],color=lcol[b]
ENDFOR
XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
set_legend,1,band_name,lcol,symbol

ymax=max(mean_ARD[max_col[0]+1:ncollects-1,0:nbands-1,0,0,1,0],min=ymin)

title1='Cool-down BCS Absolute Radiance Difference, (SRV0545-6)'
plot,T_obc[0,max_col[0]+1:ncollects-1],mean_ARD[max_col[0]+1:ncollects-1,0,0,0,1,0],xtit='OBC Temperature (K)',ytit='BCS ARD',yrange=[ymin,ymax], $
  xrange=[260,320],charsize=1.2,charthick=5,/nodata
FOR b=0, nbands-1 DO BEGIN
    oplot,T_obc[0,max_col[0]+1:ncollects-1],mean_ARD[max_col[0]+1:ncollects-1,b,0,0,1,0],symsize=1,color=lcol[b],psym=symbol[b]
    oplot,T_obc[0,max_col[0]+1:ncollects-1],mean_ARD[max_col[0]+1:ncollects-1,b,0,0,1,0],color=lcol[b]
ENDFOR
XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
set_legend,1,band_name,lcol,symbol

ymax=max(mean_ARD[0:ncollects-1,0:nbands-1,0,0,1,0],min=ymin)

title1='BCS Absolute Radiance Difference, (SRV0545-6)'
plot,T_obc[0,0:max_col[0]],mean_ARD[0:max_col[0],0,0,0,1,0],xtit='OBC Temperature (K)',ytit='BCS ARD',yrange=[ymin,ymax], $
  xrange=[260,320],charsize=1.2,charthick=5,/nodata
FOR b=0, nbands-1 DO BEGIN
    oplot,T_obc[0,0:ncollects-1],mean_ARD[0:ncollects-1,b,0,0,1,0],symsize=1,color=lcol[b],psym=symbol[b]
    oplot,T_obc[0,0:ncollects-1],mean_ARD[0:ncollects-1,b,0,0,1,0],color=lcol[b]
ENDFOR
XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
set_legend,1,band_name,lcol,symbol

device,/close

;*****************************************************************************
;  Plot the OBC ARD in a .ps file.
;*****************************************************************************

set_multicolor,xsave,ysave,psave,chname,lcol,symbol,red,green,blue
set_plot,'ps'
outfname=outpath+a2[a3-3]+'.'+a2[a3-2]+'.'+a2[a3-1]+'.ard.obc.ps'
device,/landscape,filename=outfname,/color
!p.multi=[0,1,1]
!p.position=0

;*****************************************************************************
;  Plot the ARD per detector for warm-up.
;*****************************************************************************

G=findgen(30)
title1='OBC Absolute Radiance Difference, (SRV0545-6)'
FOR b=0, nbands-1 DO BEGIN
    title2=band_name[b]+' Warm-up, HAM A (quadratic poly_fit)'

    ymax=max(ARD_obc[0:max_col[0],b,0,mindet[b]:detectors[b]-1,0,1,0],min=ymin)

    plot,T_obc[0,0:max_col[0]],ARD_obc[0:max_col[0],b,0,0,0,1,0],xtit='OBC Temperature (K)',ytit='OBC ARD',yrange=[ymin,ymax], $
      xrange=[260,320],title=title2,charsize=1.2,charthick=5,/nodata

    FOR id=0,detectors[b]-1 DO BEGIN
        oplot,T_obc[0,0:max_col[0]],ARD_obc[0:max_col[0],b,0,id,0,1,0],symsize=1,color=lcol[id],psym=symbol[id]
        oplot,T_obc[0,0:max_col[0]],ARD_obc[0:max_col[0],b,0,id,0,1,0],color=lcol[id]
    ENDFOR
    XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
    IF band_type[b] EQ 0 THEN set_legend,1,chname,lcol,symbol
    IF band_type[b] EQ 1 THEN set_legend,2,chname,lcol,symbol
ENDFOR

;*****************************************************************************
;  Plot the ARD per detector for cool-down.
;*****************************************************************************

G=findgen(30)
title1='OBC Absolute Radiance Difference, (SRV0545-6)'
FOR b=0, nbands-1 DO BEGIN
    title2=band_name[b]+' Cool-down, HAM A (quadratic poly_fit)'

    ymax=max(ARD_obc[max_col[0]+1:ncollects-1,b,0,mindet[b]:detectors[b]-1,0,1,0],min=ymin)

    plot,T_obc[0,max_col[0]+1:ncollects-1],ARD_obc[max_col[0]+1:ncollects-1,b,0,0,0,1,0],xtit='OBC Temperature (K)',ytit='OBC ARD',yrange=[ymin,ymax], $
      xrange=[260,320],title=title2,charsize=1.2,charthick=5,/nodata

    FOR id=0,detectors[b]-1 DO BEGIN
        oplot,T_obc[0,max_col[0]+1:ncollects-1],ARD_obc[max_col[0]+1:ncollects-1,b,0,id,0,1,0],symsize=1,color=lcol[id],psym=symbol[id]
        oplot,T_obc[0,max_col[0]+1:ncollects-1],ARD_obc[max_col[0]+1:ncollects-1,b,0,id,0,1,0],color=lcol[id]
    ENDFOR
    XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
    IF band_type[b] EQ 0 THEN set_legend,1,chname,lcol,symbol
    IF band_type[b] EQ 1 THEN set_legend,2,chname,lcol,symbol
ENDFOR

;*****************************************************************************
;  Plot the mean ARD for warm-up and cool-down separately and together.
;*****************************************************************************

ymax=max(mean_ARD_obc[0:max_col[0],0:nbands-1,0,0,1,0],min=ymin)

title1='Warm-up OBC Absolute Radiance Difference, (SRV0545-6)'
plot,T_obc[0,0:max_col[0]],mean_ARD_obc[0:max_col[0],0,0,0,1,0],xtit='OBC Temperature (K)',ytit='OBC ARD',yrange=[ymin,ymax], $
  xrange=[260,320],charsize=1.2,charthick=5,/nodata
FOR b=0, nbands-1 DO BEGIN
    oplot,T_obc[0,0:max_col[0]],mean_ARD_obc[0:max_col[0],b,0,0,1,0],symsize=1,color=lcol[b],psym=symbol[b]
    oplot,T_obc[0,0:max_col[0]],mean_ARD_obc[0:max_col[0],b,0,0,1,0],color=lcol[b]
ENDFOR
XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
set_legend,1,band_name,lcol,symbol

ymax=max(mean_ARD_obc[max_col[0]+1:ncollects-1,0:nbands-1,0,0,1,0],min=ymin)

title1='Cool-down OBC Absolute Radiance Difference, (SRV0545-6)'
plot,T_obc[0,max_col[0]+1:ncollects-1],mean_ARD[max_col[0]+1:ncollects-1,0,0,0,1,0],xtit='OBC Temperature (K)',ytit='OBC ARD',yrange=[ymin,ymax], $
  xrange=[260,320],charsize=1.2,charthick=5,/nodata
FOR b=0, nbands-1 DO BEGIN
    oplot,T_obc[0,max_col[0]+1:ncollects-1],mean_ARD_obc[max_col[0]+1:ncollects-1,b,0,0,1,0],symsize=1,color=lcol[b],psym=symbol[b]
    oplot,T_obc[0,max_col[0]+1:ncollects-1],mean_ARD_obc[max_col[0]+1:ncollects-1,b,0,0,1,0],color=lcol[b]
ENDFOR
XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
set_legend,1,band_name,lcol,symbol

ymax=max(mean_ARD_obc[0:ncollects-1,0:nbands-1,0,0,1,0],min=ymin)

title1='OBC Absolute Radiance Difference, (SRV0545-6)'
plot,T_obc[0,0:max_col[0]],mean_ARD_obc[0:max_col[0],0,0,0,1,0],xtit='OBC Temperature (K)',ytit='OBC ARD',yrange=[ymin,ymax], $
  xrange=[260,320],charsize=1.2,charthick=5,/nodata
FOR b=0, nbands-1 DO BEGIN
    oplot,T_obc[0,0:ncollects-1],mean_ARD_obc[0:ncollects-1,b,0,0,1,0],symsize=1,color=lcol[b],psym=symbol[b]
    oplot,T_obc[0,0:ncollects-1],mean_ARD_obc[0:ncollects-1,b,0,0,1,0],color=lcol[b]
ENDFOR
XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
set_legend,1,band_name,lcol,symbol

device,/close

;*****************************************************************************
;  Plot the OBC RRU in a .ps file.
;*****************************************************************************

set_multicolor,xsave,ysave,psave,chname,lcol,symbol,red,green,blue
set_plot,'ps'
outfname=outpath+a2[a3-3]+'.'+a2[a3-2]+'.'+a2[a3-1]+'.rru.bcs.ps'
device,/landscape,filename=outfname,/color
!p.multi=[0,1,1]
!p.position=0

;*****************************************************************************
;  Plot the RRU per detector for warm-up.
;*****************************************************************************

G=findgen(30)
title1='BCS Relative Response Uniformity, (SRV0613)'
FOR b=0, nbands-1 DO BEGIN
    title2=band_name[b]+' Warm-up, HAM A (quadratic poly_fit)'

    ymax=max(RRU_BCS_det[0:max_col[0],b,0,mindet[b]:detectors[b]-1,0,1,0],min=ymin)

    plot,T_obc[0,0:max_col[0]],RRU_BCS_det[0:max_col[0],b,0,0,0,1,0],xtit='OBC Temperature (K)',ytit='BCS RRU',yrange=[ymin,ymax], $
      xrange=[260,320],title=title2,charsize=1.2,charthick=5,/nodata

    FOR id=0,detectors[b]-1 DO BEGIN
        oplot,T_obc[0,0:max_col[0]],RRU_BCS_det[0:max_col[0],b,0,id,0,1,0],symsize=1,color=lcol[id],psym=symbol[id]
        oplot,T_obc[0,0:max_col[0]],RRU_BCS_det[0:max_col[0],b,0,id,0,1,0],color=lcol[id]
    ENDFOR
    XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
    IF band_type[b] EQ 0 THEN set_legend,1,chname,lcol,symbol
    IF band_type[b] EQ 1 THEN set_legend,2,chname,lcol,symbol
ENDFOR

;*****************************************************************************
;  Plot the RRU per detector for cool-down.
;*****************************************************************************

G=findgen(30)
title1='BCS Relative Response Uniformity, (SRV0613)'
FOR b=0, nbands-1 DO BEGIN
    title2=band_name[b]+' Cool-down, HAM A (quadratic poly_fit)'

    ymax=max(RRU_BCS_det[max_col[0]+1:ncollects-1,b,0,mindet[b]:detectors[b]-1,0,1,0],min=ymin)

    plot,T_obc[0,max_col[0]+1:ncollects-1],RRU_BCS_det[max_col[0]+1:ncollects-1,b,0,0,0,1,0],xtit='OBC Temperature (K)',ytit='BCS RRU',yrange=[ymin,ymax], $
      xrange=[260,320],title=title2,charsize=1.2,charthick=5,/nodata

    FOR id=0,detectors[b]-1 DO BEGIN
        oplot,T_obc[0,max_col[0]+1:ncollects-1],RRU_BCS_det[max_col[0]+1:ncollects-1,b,0,id,0,1,0],symsize=1,color=lcol[id],psym=symbol[id]
        oplot,T_obc[0,max_col[0]+1:ncollects-1],RRU_BCS_det[max_col[0]+1:ncollects-1,b,0,id,0,1,0],color=lcol[id]
    ENDFOR
    XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
    IF band_type[b] EQ 0 THEN set_legend,1,chname,lcol,symbol
    IF band_type[b] EQ 1 THEN set_legend,2,chname,lcol,symbol
ENDFOR

;*****************************************************************************
;  Plot the mean RRU for warm-up and cool-down separately and together.
;*****************************************************************************

ymax=max(RRU_OBC[0:max_col[0],0:nbands-1,0,0,1,0],min=ymin)

title1='Warm-up BCS Relative Response Uniformity, (SRV0613)'
plot,T_obc[0,0:max_col[0]],RRU_BCS[0:max_col[0],0,0,0,1,0],xtit='OBC Temperature (K)',ytit='BCS RRU',yrange=[ymin,ymax], $
  xrange=[260,320],charsize=1.2,charthick=5,/nodata
FOR b=0, nbands-1 DO BEGIN
    oplot,T_obc[0,0:max_col[0]],RRU_BCS[0:max_col[0],b,0,0,1,0],symsize=1,color=lcol[b],psym=symbol[b]
    oplot,T_obc[0,0:max_col[0]],RRU_BCS[0:max_col[0],b,0,0,1,0],color=lcol[b]
ENDFOR
XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
set_legend,1,band_name,lcol,symbol

ymax=max(RRU_BCS[max_col[0]+1:ncollects-1,0:nbands-1,0,0,1,0],min=ymin)

title1='Cool-down BCS Relative Response Uniformity, (SRV0613)'
plot,T_obc[0,max_col[0]+1:ncollects-1],RRU_BCS[max_col[0]+1:ncollects-1,0,0,0,1,0],xtit='OBC Temperature (K)',ytit='BCS RRU',yrange=[ymin,ymax], $
  xrange=[260,320],charsize=1.2,charthick=5,/nodata
FOR b=0, nbands-1 DO BEGIN
    oplot,T_obc[0,max_col[0]+1:ncollects-1],RRU_BCS[max_col[0]+1:ncollects-1,b,0,0,1,0],symsize=1,color=lcol[b],psym=symbol[b]
    oplot,T_obc[0,max_col[0]+1:ncollects-1],RRU_BCS[max_col[0]+1:ncollects-1,b,0,0,1,0],color=lcol[b]
ENDFOR
XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
set_legend,1,band_name,lcol,symbol

ymax=max(RRU_BCS[0:ncollects-1,0:nbands-1,0,0,1,0],min=ymin)

title1='BCS Relative Response Uniformity, (SRV0613)'
plot,T_obc[0,0:max_col[0]],RRU_BCS[0:max_col[0],0,0,0,1,0],xtit='OBC Temperature (K)',ytit='BCS RRU',yrange=[ymin,ymax], $
  xrange=[260,320],charsize=1.2,charthick=5,/nodata
FOR b=0, nbands-1 DO BEGIN
    oplot,T_obc[0,0:ncollects-1],RRU_BCS[0:ncollects-1,b,0,0,1,0],symsize=1,color=lcol[b],psym=symbol[b]
    oplot,T_obc[0,0:ncollects-1],RRU_BCS[0:ncollects-1,b,0,0,1,0],color=lcol[b]
ENDFOR
XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
set_legend,1,band_name,lcol,symbol

device,/close

;*****************************************************************************
;  Plot the OBC RRU in a .ps file.
;*****************************************************************************

set_multicolor,xsave,ysave,psave,chname,lcol,symbol,red,green,blue
set_plot,'ps'
outfname=outpath+a2[a3-3]+'.'+a2[a3-2]+'.'+a2[a3-1]+'.rru.obc.ps'
device,/landscape,filename=outfname,/color
!p.multi=[0,1,1]
!p.position=0

;*****************************************************************************
;  Plot the RRU per detector for warm-up.
;*****************************************************************************

G=findgen(30)
title1='OBC Relative Response Uniformity, (SRV0613)'
FOR b=0, nbands-1 DO BEGIN
    title2=band_name[b]+' Warm-up, HAM A (quadratic poly_fit)'

    ymax=max(RRU_OBC_det[0:max_col[0],b,0,mindet[b]:detectors[b]-1,0,1,0],min=ymin)

    plot,T_obc[0,0:max_col[0]],RRU_OBC_det[0:max_col[0],b,0,0,0,1,0],xtit='OBC Temperature (K)',ytit='OBC RRU',yrange=[ymin,ymax], $
      xrange=[260,320],title=title2,charsize=1.2,charthick=5,/nodata

    FOR id=0,detectors[b]-1 DO BEGIN
        oplot,T_obc[0,0:max_col[0]],RRU_OBC_det[0:max_col[0],b,0,id,0,1,0],symsize=1,color=lcol[id],psym=symbol[id]
        oplot,T_obc[0,0:max_col[0]],RRU_OBC_det[0:max_col[0],b,0,id,0,1,0],color=lcol[id]
    ENDFOR
    XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
    IF band_type[b] EQ 0 THEN set_legend,1,chname,lcol,symbol
    IF band_type[b] EQ 1 THEN set_legend,2,chname,lcol,symbol
ENDFOR

;*****************************************************************************
;  Plot the RRU per detector for cool-down.
;*****************************************************************************

G=findgen(30)
title1='OBC Relative Response Uniformity, (SRV0613)'
FOR b=0, nbands-1 DO BEGIN
    title2=band_name[b]+' Cool-down, HAM A (quadratic poly_fit)'

    ymax=max(RRU_OBC_det[max_col[0]+1:ncollects-1,b,0,mindet[b]:detectors[b]-1,0,1,0],min=ymin)

    plot,T_obc[0,max_col[0]+1:ncollects-1],RRU_OBC_det[max_col[0]+1:ncollects-1,b,0,0,0,1,0],xtit='OBC Temperature (K)',ytit='OBC RRU',yrange=[ymin,ymax], $
      xrange=[260,320],title=title2,charsize=1.2,charthick=5,/nodata

    FOR id=0,detectors[b]-1 DO BEGIN
        oplot,T_obc[0,max_col[0]+1:ncollects-1],RRU_OBC_det[max_col[0]+1:ncollects-1,b,0,id,0,1,0],symsize=1,color=lcol[id],psym=symbol[id]
        oplot,T_obc[0,max_col[0]+1:ncollects-1],RRU_OBC_det[max_col[0]+1:ncollects-1,b,0,id,0,1,0],color=lcol[id]
    ENDFOR
    XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
    IF band_type[b] EQ 0 THEN set_legend,1,chname,lcol,symbol
    IF band_type[b] EQ 1 THEN set_legend,2,chname,lcol,symbol
ENDFOR

;*****************************************************************************
;  Plot the mean RRU for warm-up and cool-down separately and together.
;*****************************************************************************

ymax=max(RRU_OBC[0:max_col[0],0:nbands-1,0,0,1,0],min=ymin)

title1='Warm-up OBC Relative Response Uniformity, (SRV0613)'
plot,T_obc[0,0:max_col[0]],RRU_OBC[0:max_col[0],0,0,0,1,0],xtit='OBC Temperature (K)',ytit='OBC RRU',yrange=[ymin,ymax], $
  xrange=[260,320],charsize=1.2,charthick=5,/nodata
FOR b=0, nbands-1 DO BEGIN
    oplot,T_obc[0,0:max_col[0]],RRU_OBC[0:max_col[0],b,0,0,1,0],symsize=1,color=lcol[b],psym=symbol[b]
    oplot,T_obc[0,0:max_col[0]],RRU_OBC[0:max_col[0],b,0,0,1,0],color=lcol[b]
ENDFOR
XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
set_legend,1,band_name,lcol,symbol

ymax=max(RRU_OBC[max_col[0]+1:ncollects-1,0:nbands-1,0,0,1,0],min=ymin)

title1='Cool-down OBC Relative Response Uniformity, (SRV0613)'
plot,T_obc[0,max_col[0]+1:ncollects-1],RRU_OBC[max_col[0]+1:ncollects-1,0,0,0,1,0],xtit='OBC Temperature (K)',ytit='OBC RRU',yrange=[ymin,ymax], $
  xrange=[260,320],charsize=1.2,charthick=5,/nodata
FOR b=0, nbands-1 DO BEGIN
    oplot,T_obc[0,max_col[0]+1:ncollects-1],RRU_OBC[max_col[0]+1:ncollects-1,b,0,0,1,0],symsize=1,color=lcol[b],psym=symbol[b]
    oplot,T_obc[0,max_col[0]+1:ncollects-1],RRU_OBC[max_col[0]+1:ncollects-1,b,0,0,1,0],color=lcol[b]
ENDFOR
XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
set_legend,1,band_name,lcol,symbol

ymax=max(RRU_OBC[0:ncollects-1,0:nbands-1,0,0,1,0],min=ymin)

title1='OBC Relative Response Uniformity, (SRV0613)'
plot,T_obc[0,0:max_col[0]],RRU_OBC[0:max_col[0],0,0,0,1,0],xtit='OBC Temperature (K)',ytit='OBC RRU',yrange=[ymin,ymax], $
  xrange=[260,320],charsize=1.2,charthick=5,/nodata
FOR b=0, nbands-1 DO BEGIN
    oplot,T_obc[0,0:ncollects-1],RRU_OBC[0:ncollects-1,b,0,0,1,0],symsize=1,color=lcol[b],psym=symbol[b]
    oplot,T_obc[0,0:ncollects-1],RRU_OBC[0:ncollects-1,b,0,0,1,0],color=lcol[b]
ENDFOR
XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
set_legend,1,band_name,lcol,symbol

device,/close

END
