;*****************************************************************************
;  RC5 Part 2 graphs the delta OBC radiance versus dn.
;
;  Output:
;  1) postscript files containing graphs.
;  
;  v1.0 - 04/02/2008 - Jeff McIntire
;  v2.0 - 03/31/2009 - Jeff McIntire
;   -- Added plots
;*****************************************************************************

PRO RC5_OBC_view, infile

close,/all

;*****************************************************************************
;  Read in data.
;*****************************************************************************

nlines=File_Lines(infile)
ab=''
header=strarr(1)
inpath=strarr(1)		; Input path.
outpath=strarr(1)		; Output path.
rvs_in=strarr(1)
param_in=strarr(1)
rsrpath=strarr(1)
maxscan=intarr(1)               ; # of scans

openr,lun,infile,/Get_Lun	
readf,lun,header	
readf,lun,inpath
readf,lun,outpath
readf,lun,rvs_in
readf,lun,param_in
readf,lun,rsrpath
readf,lun,maxscan
Free_Lun,lun

maxscan=maxscan[0]

a2=strsplit(outpath,'/',/Extract)
a3=N_ELEMENTS(a2)

restore,'general.TEB.2.sav'
restore,outpath+a2[a3-3]+'.'+a2[a3-2]+'.'+a2[a3-1]+'.rad.sav'
restore,outpath+a2[a3-3]+'.'+a2[a3-2]+'.'+a2[a3-1]+'.dn.sav'
restore,outpath+a2[a3-3]+'.'+a2[a3-2]+'.'+a2[a3-1]+'.rg.sav'
restore,outpath+a2[a3-3]+'.'+a2[a3-2]+'.'+a2[a3-1]+'.temp.sav'

;*****************************************************************************
;  Some definitions.
;*****************************************************************************

D=findgen(4000)
E=findgen(30000)
F=fltarr(30000)
HAM=['A','B']
SS=[' SS1',' SS2']
HAM_SS=['HAM A, SS1','HAM B, SS1','HAM A, SS2','HAM B, SS2'] 

;*****************************************************************************
;  Scan average data.
;*****************************************************************************

rg=fltarr(nbands,nham,maxdet,maxsubsets,4,12,2)
dn_1=fltarr(ncollects,nbands,nham,maxdet,maxsubsets)
dL_fit_1=fltarr(ncollects,nbands,nham,maxdet,maxsubsets,12,2)
rad_OBC_x=fltarr(ncollects,nbands,nham,maxdet,maxsubsets,2)

FOR rsr=0, 1 DO BEGIN
    FOR b=0, nbands-1 DO BEGIN
        FOR is=0, subsets[b]-1 DO BEGIN
            FOR ih=0, nham-1 DO BEGIN
                FOR id=0, detectors[b]-1 DO BEGIN
                    FOR i=0, 3 DO BEGIN
                        FOR j=0, 11 DO BEGIN
                            rg[b,ih,id,is,i,j,rsr]=mean(rg_1[b,ih,id,is,0:maxscan/2-1,i,j,rsr])
                        ENDFOR
                    ENDFOR
                    FOR col=0, ncollects-1 DO BEGIN
                        rad_OBC_x[col,b,ih,id,is,rsr]=mean(rad_OBC_scan_x[col,b,ih,id,is,0:maxscan/2-1,rsr])
                        dn_1[col,b,ih,id,is]=mean(dn_x[col,b,ih,id,is,0:maxscan/2-1])
                        FOR j=0, 11 DO BEGIN
                            dL_fit_1[col,b,ih,id,is,j,rsr]=mean(dL_fit[col,b,ih,id,is,0:maxscan/2-1,j,rsr])
                        ENDFOR
                    ENDFOR
                ENDFOR
            ENDFOR
        ENDFOR
    ENDFOR
ENDFOR

;*****************************************************************************
;  Plot warm-up coefficients versus detector (from calibration equation).
;*****************************************************************************

set_multicolor,xsave,ysave,psave,chname,lcol,symbol,red,green,blue
set_plot,'ps'
outfname=outpath+a2[a3-3]+'.'+a2[a3-2]+'.'+a2[a3-1]+'.warm_up.coeff.ps'
device,/landscape,filename=outfname,/color

; Plot all bands on one page, then 4 bands to a page.
FOR i=0, 1 DO BEGIN
    IF i EQ 0 THEN !p.multi=[0,3,3]
    IF i EQ 1 THEN !p.multi=[0,2,2]
    !p.position=0
        
    ; Plot a0.
    FOR b=0, nbands-1 DO BEGIN
        title1='Detector Variation in a0 (warm-up)'
        title2=band_name[b]+' (quadratic poly_fit)'
        
        ymax=max(rg[b,0:1,0:detectors[b]-1,0:subsets[b]-1,0,1,0],min=ymin)
        
        plot,D[0:detectors[b]-1]+1,rg[b,0,0:detectors[b]-1,0,0,1,0],yrange=[ymin,ymax],xrange=[0,detectors[b]], $
          xtit='Detector',ytit='a0',title=title2,charsize=1.2,charthick=5,thick=3,/nodata
        j=0
        FOR is=0, subsets[b]-1 DO BEGIN
            FOR ih=0, nham-1 DO BEGIN
                oplot,D[0:detectors[b]-1]+1,rg[b,ih,0:detectors[b]-1,is,0,1,0],symsize=1,color=lcol[j],psym=symbol[j],thick=3
                oplot,D[0:detectors[b]-1]+1,rg[b,ih,0:detectors[b]-1,is,0,1,0],color=lcol[j],thick=3
                j=j+1
            ENDFOR
        ENDFOR
        XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
        set_legend,1,HAM_SS,lcol,symbol
    ENDFOR
    
    IF i EQ 0 THEN !p.multi=[0,3,3]
    IF i EQ 1 THEN !p.multi=[0,2,2]
    !p.position=0
    
    ; Plot 1/a1.
    FOR b=0, nbands-1 DO BEGIN
        title1='Detector Variation in Gain (1/a1) (warm-up)'
        title2=band_name[b]+' (quadratic poly_fit)'
        
        ymax=max(1/rg[b,0:1,0:detectors[b]-1,0:subsets[b]-1,1,1,0],min=ymin)
        
        plot,D[0:detectors[b]-1]+1,1/rg[b,0,0:detectors[b]-1,0,1,1,0],yrange=[ymin,ymax],xrange=[0,detectors[b]], $
          xtit='Detector',ytit='Gain (1/a1)',title=title2,charsize=1.2,charthick=5,thick=3,/nodata
        j=0
        FOR is=0, subsets[b]-1 DO BEGIN
            FOR ih=0, nham-1 DO BEGIN
                oplot,D[0:detectors[b]-1]+1,1/rg[b,ih,0:detectors[b]-1,is,1,1,0],symsize=1,color=lcol[j],psym=symbol[j],thick=3
                oplot,D[0:detectors[b]-1]+1,1/rg[b,ih,0:detectors[b]-1,is,1,1,0],color=lcol[j],thick=3
                j=j+1
            ENDFOR
        ENDFOR
        XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
        set_legend,1,HAM_SS,lcol,symbol
    ENDFOR
    
    IF i EQ 0 THEN !p.multi=[0,3,3]
    IF i EQ 1 THEN !p.multi=[0,2,2]
    !p.position=0
    
    ; Plot a2.
    FOR b=0, nbands-1 DO BEGIN
        title1='Detector Variation in a2 (warm-up)'
        title2=band_name[b]+' (quadratic poly_fit)'
        
        ymax=max(rg[b,0:1,0:detectors[b]-1,0:subsets[b]-1,2,1,0],min=ymin)
        
        plot,D[0:detectors[b]-1]+1,rg[b,0,0:detectors[b]-1,0,2,1,0],yrange=[ymin,ymax],xrange=[0,detectors[b]], $
          xtit='Detector',ytit='a2',title=title2,charsize=1.2,charthick=5,thick=3,/nodata
        j=0
        FOR is=0, subsets[b]-1 DO BEGIN
            FOR ih=0, nham-1 DO BEGIN
                oplot,D[0:detectors[b]-1]+1,rg[b,ih,0:detectors[b]-1,is,2,1,0],symsize=1,color=lcol[j],psym=symbol[j],thick=3
                oplot,D[0:detectors[b]-1]+1,rg[b,ih,0:detectors[b]-1,is,2,1,0],color=lcol[j],thick=3
                j=j+1
            ENDFOR
        ENDFOR
        XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
        set_legend,1,HAM_SS,lcol,symbol
    ENDFOR
ENDFOR

device,/close

;*****************************************************************************
;  Plot cool-down coefficients versus detector (from calibration equation).
;*****************************************************************************

set_multicolor,xsave,ysave,psave,chname,lcol,symbol,red,green,blue
set_plot,'ps'
outfname=outpath+a2[a3-3]+'.'+a2[a3-2]+'.'+a2[a3-1]+'.cool_down.coeff.ps'
device,/landscape,filename=outfname,/color

; Plot all bands on one page, then 4 bands to a page.
FOR i=0, 1 DO BEGIN
    IF i EQ 0 THEN !p.multi=[0,3,3]
    IF i EQ 1 THEN !p.multi=[0,2,2]
    !p.position=0
        
    ; Plot a0.
    FOR b=0, nbands-1 DO BEGIN
        title1='Detector Variation in a0 (cool-down)'
        title2=band_name[b]+' (quadratic poly_fit)'
        
        ymax=max(rg[b,0:1,0:detectors[b]-1,0:subsets[b]-1,0,7,0],min=ymin)
        
        plot,D[0:detectors[b]-1]+1,rg[b,0,0:detectors[b]-1,0,0,7,0],yrange=[ymin,ymax],xrange=[0,detectors[b]], $
          xtit='Detector',ytit='a0',title=title2,charsize=1.2,charthick=5,thick=3,/nodata
        j=0
        FOR is=0, subsets[b]-1 DO BEGIN
            FOR ih=0, nham-1 DO BEGIN
                oplot,D[0:detectors[b]-1]+1,rg[b,ih,0:detectors[b]-1,is,0,7,0],symsize=1,color=lcol[j],psym=symbol[j],thick=3
                oplot,D[0:detectors[b]-1]+1,rg[b,ih,0:detectors[b]-1,is,0,7,0],color=lcol[j],thick=3
                j=j+1
            ENDFOR
        ENDFOR
        XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
        set_legend,1,HAM_SS,lcol,symbol
    ENDFOR
    
    IF i EQ 0 THEN !p.multi=[0,3,3]
    IF i EQ 1 THEN !p.multi=[0,2,2]
    !p.position=0
    
    ; Plot 1/a1.
    FOR b=0, nbands-1 DO BEGIN
        title1='Detector Variation in Gain (1/a1) (cool-down)'
        title2=band_name[b]+' (quadratic poly_fit)'
        
        ymax=max(1/rg[b,0:1,0:detectors[b]-1,0:subsets[b]-1,1,7,0],min=ymin)
        
        plot,D[0:detectors[b]-1]+1,1/rg[b,0,0:detectors[b]-1,0,1,7,0],yrange=[ymin,ymax],xrange=[0,detectors[b]], $
          xtit='Detector',ytit='Gain (1/a1)',title=title2,charsize=1.2,charthick=5,thick=3,/nodata
        j=0
        FOR is=0, subsets[b]-1 DO BEGIN
            FOR ih=0, nham-1 DO BEGIN
                oplot,D[0:detectors[b]-1]+1,1/rg[b,ih,0:detectors[b]-1,is,1,7,0],symsize=1,color=lcol[j],psym=symbol[j],thick=3
                oplot,D[0:detectors[b]-1]+1,1/rg[b,ih,0:detectors[b]-1,is,1,7,0],color=lcol[j],thick=3
                j=j+1
            ENDFOR
        ENDFOR
        XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
        set_legend,1,HAM_SS,lcol,symbol
    ENDFOR
    
    IF i EQ 0 THEN !p.multi=[0,3,3]
    IF i EQ 1 THEN !p.multi=[0,2,2]
    !p.position=0
    
    ; Plot a2.
    FOR b=0, nbands-1 DO BEGIN
        title1='Detector Variation in a2 (cool-down)'
        title2=band_name[b]+' (quadratic poly_fit)'
        
        ymax=max(rg[b,0:1,0:detectors[b]-1,0:subsets[b]-1,2,7,0],min=ymin)
        
        plot,D[0:detectors[b]-1]+1,rg[b,0,0:detectors[b]-1,0,2,7,0],yrange=[ymin,ymax],xrange=[0,detectors[b]], $
          xtit='Detector',ytit='a2',title=title2,charsize=1.2,charthick=5,thick=3,/nodata
        j=0
        FOR is=0, subsets[b]-1 DO BEGIN
            FOR ih=0, nham-1 DO BEGIN
                oplot,D[0:detectors[b]-1]+1,rg[b,ih,0:detectors[b]-1,is,2,7,0],symsize=1,color=lcol[j],psym=symbol[j],thick=3
                oplot,D[0:detectors[b]-1]+1,rg[b,ih,0:detectors[b]-1,is,2,7,0],color=lcol[j],thick=3
                j=j+1
            ENDFOR
        ENDFOR
        XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
        set_legend,1,HAM_SS,lcol,symbol
    ENDFOR
ENDFOR

device,/close

;*****************************************************************************
;  Find warm-up and cool-down collects.
;*****************************************************************************

F=findgen(ncollects)
FOR ih=0, nham-1 DO BEGIN
    max_col=WHERE(T_obc[ih,*] EQ max(T_obc[ih,*]))
    warm=WHERE(F[0:ncollects-1] LE max_col[0])
    cool=WHERE(F[0:ncollects-1] GT max_col[0])
ENDFOR

;*****************************************************************************
;  Plot delta OBC radiance versus dn with fit (quadratic pol_fit)
;  along with the fractional fitting residual.
;*****************************************************************************

set_multicolor,xsave,ysave,psave,chname,lcol,symbol,red,green,blue
set_plot,'ps'
outfname=outpath+a2[a3-3]+'.'+a2[a3-2]+'.'+a2[a3-1]+'.warm_up.fits_1.ps'
device,/landscape,filename=outfname,/color

; Calibration equation.
; Plot all bands on one page, then one band to a page with residual.
title1='dL_OBC vs dn'
FOR ih=0, nham-1 DO BEGIN
    FOR i=0, 1 DO BEGIN
        IF i EQ 0 THEN !p.multi=[0,3,3]
        IF i EQ 1 THEN !p.multi=[0,1,2]
        !p.position=0

        ; Plot dn vs dL_BCS.
        FOR b=0, nbands-1 DO BEGIN
            IF band_type[b] EQ 0 THEN title2=band_name[b]+', HAM= '+HAM[ih]+' (quadratic poly_fit)'
            IF band_type[b] EQ 1 THEN title2=band_name[b]+' SS1, HAM= '+HAM[ih]+' (quadratic poly_fit)'
            
            ymax=max(rad_OBC_x[warm,b,ih,*,0,0])
            xmax=max(dn_1[warm,b,ih,*,0])

            plot,rad_OBC_x[warm,b,ih,1,0,0],dn_1[warm,b,ih,1,0],xrange=[0,ymax],yrange=[0,xmax], $
              xtit='dL_OBC (Wm-2sr-1um-1)',ytit='dn',title=title2,charsize=1.2,charthick=5,thick=3,/nodata
            
            FOR id=0, detectors[b]-1 DO BEGIN
                oplot,rad_OBC_x[warm,b,ih,id,0,0],dn_1[warm,b,ih,id,0],symsize=1,color=lcol[id],psym=symbol[id],thick=3
                ; Use fits from response equation to fit the axes.
                oplot,rg[b,ih,id,0,0,4,0]+rg[b,ih,id,0,1,4,0]*D+rg[b,ih,id,0,2,4,0]*D^2,color=lcol[id],thick=3
            ENDFOR
                oplot,[L_max[b,0],L_max[b,0]],[-100,10000],symsize=1,color=lcol[1],linestyle=2,thick=3
                oplot,[L_typ[b,0],L_typ[b,0]],[-100,10000],symsize=1,color=lcol[2],linestyle=2,thick=3
                oplot,[L_min[b,0],L_min[b,0]],[-100,10000],symsize=1,color=lcol[3],linestyle=2,thick=3
            
            XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5

            ; Plot fractional fitting residual in percent.
            IF i EQ 1 THEN BEGIN
                ymax=max(100.*dL_fit_1[warm,b,ih,0:detectors[b]-1,0,1,0],min=ymin)
                
                plot,rad_OBC_x[warm,b,ih,0,is,0],100.*dL_fit_1[warm,b,ih,0,0,1,0],xtit='dL_OBC (Wm-2sr-1um-1)',ytit='Radiance Residual (%)', $
                  xrange=[0,L_max[b,0]],yrange=[ymin,ymax],title=title1,charsize=1.2,charthick=5,thick=3,/nodata
                
                FOR id=0, detectors[b]-1 DO BEGIN
                    oplot,rad_OBC_x[warm,b,ih,id,0,0],100.*dL_fit_1[warm,b,ih,id,0,1,0],symsize=1,color=lcol[id],psym=symbol[id],thick=3
                    oplot,rad_OBC_x[warm,b,ih,id,0,0],100.*dL_fit_1[warm,b,ih,id,0,1,0],color=lcol[id],thick=3
                ENDFOR
                oplot,[L_max[b,0],L_max[b,0]],[-100,10000],symsize=1,color=lcol[1],linestyle=2,thick=3
                oplot,[L_typ[b,0],L_typ[b,0]],[-100,10000],symsize=1,color=lcol[2],linestyle=2,thick=3
                oplot,[L_min[b,0],L_min[b,0]],[-100,10000],symsize=1,color=lcol[3],linestyle=2,thick=3

                XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
                IF band_type[b] EQ 0 THEN set_legend,1,chname,lcol,symbol
                IF band_type[b] EQ 1 THEN set_legend,2,chname,lcol,symbol
            ENDIF
        ENDFOR
    ENDFOR
ENDFOR

; Response equation.
; Plot all bands on one page, then one band to a page with residual.
title1='dn vs dL_OBC'
FOR ih=0, nham-1 DO BEGIN
    FOR i=0, 1 DO BEGIN
        IF i EQ 0 THEN !p.multi=[0,3,3]
        IF i EQ 1 THEN !p.multi=[0,1,2]
        !p.position=0

        ; Plot dn vs dL_OBC.
        FOR b=0, nbands-1 DO BEGIN
            IF band_type[b] EQ 0 THEN title2=band_name[b]+', HAM= '+HAM[ih]+' (quadratic poly_fit)'
            IF band_type[b] EQ 1 THEN title2=band_name[b]+' SS1, HAM= '+HAM[ih]+' (quadratic poly_fit)'
            
            xmax=max(rad_OBC_x[warm,b,ih,*,0,0])
            ymax=max(dn_1[warm,b,ih,*,0])
            
            plot,rad_OBC_x[warm,b,ih,1,0,0],dn_1[warm,b,ih,1,0],yrange=[0,ymax],xrange=[0,xmax], $
              xtit='dL_OBC (Wm-2sr-1um-1)',ytit='dn',title=title2,charsize=1.2,charthick=5,thick=3,/nodata
            
            FOR id=0, detectors[b]-1 DO BEGIN
                oplot,rad_OBC_x[warm,b,ih,id,0,0],dn_1[warm,b,ih,id,0],symsize=1,color=lcol[id],psym=symbol[id],thick=3
                oplot,rg[b,ih,id,0,0,4,0]+rg[b,ih,id,0,1,4,0]*D+rg[b,ih,id,0,2,4,0]*D^2,color=lcol[id],thick=3
            ENDFOR
            oplot,[L_max[b,0],L_max[b,0]],[-100,10000],symsize=1,color=lcol[1],linestyle=2,thick=3
            oplot,[L_typ[b,0],L_typ[b,0]],[-100,10000],symsize=1,color=lcol[2],linestyle=2,thick=3
            oplot,[L_min[b,0],L_min[b,0]],[-100,10000],symsize=1,color=lcol[3],linestyle=2,thick=3
            
            XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5

            ; Plot fractional fitting residual in percent.
            IF i EQ 1 THEN BEGIN
                ymax=max(100.*dL_fit_1[warm,b,ih,0:detectors[b]-1,0,4,0],min=ymin)
                
                plot,rad_OBC_x[warm,b,ih,0,is,0],dL_fit_1[warm,b,ih,0,0,4,0],xtit='dL_OBC (Wm-2sr-1um-1)',ytit='dn Residual (%)', $
                  xrange=[0,L_max[b,0]],yrange=[ymin,ymax],title=title1,charsize=1.2,charthick=5,thick=3,/nodata
                
                FOR id=0, detectors[b]-1 DO BEGIN
                    oplot,rad_OBC_x[warm,b,ih,id,0,0],100.*dL_fit_1[warm,b,ih,id,0,4,0],symsize=1,color=lcol[id],psym=symbol[id],thick=3
                    oplot,rad_OBC_x[warm,b,ih,id,0,0],100.*dL_fit_1[warm,b,ih,id,0,4,0],color=lcol[id],thick=3
                ENDFOR
                oplot,[L_max[b,0],L_max[b,0]],[-100,10000],symsize=1,color=lcol[1],linestyle=2,thick=3
                oplot,[L_typ[b,0],L_typ[b,0]],[-100,10000],symsize=1,color=lcol[2],linestyle=2,thick=3
                oplot,[L_min[b,0],L_min[b,0]],[-100,10000],symsize=1,color=lcol[3],linestyle=2,thick=3

                XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
                IF band_type[b] EQ 0 THEN set_legend,1,chname,lcol,symbol
                IF band_type[b] EQ 1 THEN set_legend,2,chname,lcol,symbol
            ENDIF
        ENDFOR
    ENDFOR
ENDFOR

device,/close

;*****************************************************************************
;  Plot delta OBC radiance versus dn with fits (linear poly_fit, quadratic pol_fit,
;  and cubic poly_fit).
;*****************************************************************************

set_multicolor,xsave,ysave,psave,chname,lcol,symbol,red,green,blue
set_plot,'ps'
outfname=outpath+a2[a3-3]+'.'+a2[a3-2]+'.'+a2[a3-1]+'.warm_up.fits_2.ps'
device,/landscape,filename=outfname,/color

title=strarr(4)

!p.multi=[0,2,3]

; Calibration equation.
FOR b=0, nbands-1 DO BEGIN
    !p.position=0

    FOR is=0, subsets[b]-1 DO BEGIN
        FOR ih=0, nham-1 DO BEGIN
            IF band_type[b] EQ 0 THEN BEGIN
                title1=band_name[b]+': dL_OBC vs dn'
                title[0]=band_name[b]+', HAM= '+HAM[ih]+' (linear poly_fit)'
                title[1]=band_name[b]+', HAM= '+HAM[ih]+' (quadratic poly_fit)'
                title[2]=band_name[b]+', HAM= '+HAM[ih]+' (cubic poly_fit)'
            ENDIF
            IF band_type[b] EQ 1 THEN BEGIN
                title1=band_name[b]+SS[is]+': dL_OBC vs dn'
                title[0]=band_name[b]+SS[is]+', '+'HAM= '+HAM[ih]+' (linear poly_fit)'
                title[1]=band_name[b]+SS[is]+', '+'HAM= '+HAM[ih]+' (quadratic poly_fit)'
                title[2]=band_name[b]+SS[is]+', '+'HAM= '+HAM[ih]+' (cubic poly_fit)'
            ENDIF
            
            ; Plot dL_BCS vs dn.
            xmax=max(L_max[b,0])
            ymax=max(dn_1[warm,b,ih,*,is])
            
            FOR j=0, 2 DO BEGIN
                plot,rad_OBC_x[warm,b,ih,1,is,0],dn_1[warm,b,ih,1,is],yrange=[0,ymax],xrange=[0,xmax], $
                  xtit='dL_OBC (Wm-2sr-1um-1)',ytit='dn',title=title[j],charsize=1.2,charthick=5,thick=3,/nodata
                
                FOR id=0, detectors[b]-1 DO BEGIN
                    oplot,rad_OBC_x[warm,b,ih,id,is,0],dn_1[warm,b,ih,id,is],symsize=1,color=lcol[id],psym=symbol[id],thick=3
                    IF j EQ 0 THEN oplot,rg[b,ih,id,is,0,j+3,0]+rg[b,ih,id,is,1,j+3,0]*D,color=lcol[id],thick=3
                    IF j EQ 1 THEN oplot,rg[b,ih,id,is,0,j+3,0]+rg[b,ih,id,is,1,j+3,0]*D $
                      +rg[b,ih,id,is,2,j+3,0]*D^2,color=lcol[id],thick=3
                    IF j EQ 2 THEN oplot,rg[b,ih,id,is,0,j+3,0]+rg[b,ih,id,is,1,j+3,0]*D $
                      +rg[b,ih,id,is,2,j+3,0]*D^2+rg[b,ih,id,is,3,j+3,0]*D^3,color=lcol[id],thick=3
                ENDFOR
                oplot,[L_max[b,0],L_max[b,0]],[-100,10000],symsize=1,color=lcol[1],linestyle=2,thick=3
                oplot,[L_typ[b,0],L_typ[b,0]],[-100,10000],symsize=1,color=lcol[2],linestyle=2,thick=3
                oplot,[L_min[b,0],L_min[b,0]],[-100,10000],symsize=1,color=lcol[3],linestyle=2,thick=3
                
                ; Plot fractional fitting residual in percent.
                xmax2=max(L_max[b,0])
                ymax3=max(100.*dL_fit_1[warm,b,ih,0:detectors[b]-1,0,j,0],min=ymin3)
                
                plot,rad_OBC_x[warm,b,ih,0,is,0],100.*dL_fit_1[warm,b,ih,0,is,j,0],xtit='dL_OBC (Wm-2sr-1um-1)',ytit='Radiance Residual (%)', $
                  xrange=[0,xmax2],yrange=[ymin3,ymax3],title=title[j],charsize=1.2,charthick=5,thick=3,/nodata
                
                FOR id=0, detectors[b]-1 DO BEGIN
                    oplot,rad_OBC_x[warm,b,ih,id,is,0],100.*dL_fit_1[warm,b,ih,id,is,j,0],symsize=1,color=lcol[id],psym=symbol[id],thick=3
                    oplot,rad_OBC_x[warm,b,ih,id,is,0],100.*dL_fit_1[warm,b,ih,id,is,j,0],color=lcol[id],thick=3
                ENDFOR
                oplot,[L_max[b,0],L_max[b,0]],[-100,10000],symsize=1,color=lcol[1],linestyle=2,thick=3
                oplot,[L_typ[b,0],L_typ[b,0]],[-100,10000],symsize=1,color=lcol[2],linestyle=2,thick=3
                oplot,[L_min[b,0],L_min[b,0]],[-100,10000],symsize=1,color=lcol[3],linestyle=2,thick=3
            ENDFOR
            XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
            IF band_type[b] EQ 0 THEN set_legend,1,chname,lcol,symbol
            IF band_type[b] EQ 1 THEN set_legend,2,chname,lcol,symbol
        ENDFOR
    ENDFOR
ENDFOR

; Response equation.
FOR b=0, nbands-1 DO BEGIN
    !p.position=0

    FOR is=0, subsets[b]-1 DO BEGIN
        FOR ih=0, nham-1 DO BEGIN
            IF band_type[b] EQ 0 THEN BEGIN
                title1=band_name[b]+': dn vs dL_OBC'
                title[0]=band_name[b]+', HAM= '+HAM[ih]+' (linear poly_fit)'
                title[1]=band_name[b]+', HAM= '+HAM[ih]+' (quadratic poly_fit)'
                title[2]=band_name[b]+', HAM= '+HAM[ih]+' (cubic poly_fit)'
            ENDIF
            IF band_type[b] EQ 1 THEN BEGIN
                title1=band_name[b]+SS[is]+': dn vs dL_OBC'
                title[0]=band_name[b]+SS[is]+', '+'HAM= '+HAM[ih]+' (linear poly_fit)'
                title[1]=band_name[b]+SS[is]+', '+'HAM= '+HAM[ih]+' (quadratic poly_fit)'
                title[2]=band_name[b]+SS[is]+', '+'HAM= '+HAM[ih]+' (cubic poly_fit)'
            ENDIF
            
            ; Plot dn vs dL_OBC.
            xmax=max(L_max[b,0])
            ymax=max(dn_1[*,b,ih,*,is])
            
            FOR j=3, 5 DO BEGIN
                plot,rad_OBC_x[warm,b,ih,1,is,0],dn_1[warm,b,ih,1,is],yrange=[0,ymax],xrange=[0,xmax], $
                  xtit='dL_OBC (Wm-2sr-1um-1)',ytit='dn',title=title[j-3],charsize=1.2,charthick=5,thick=3,/nodata
                
                FOR id=0, detectors[b]-1 DO BEGIN
                    oplot,rad_OBC_x[warm,b,ih,id,is,0],dn_1[warm,b,ih,id,is],symsize=1,color=lcol[id],psym=symbol[id],thick=3
                    IF j EQ 3 THEN oplot,rg[b,ih,id,is,0,j,0]+rg[b,ih,id,is,1,j,0]*D,color=lcol[id],thick=3
                    IF j EQ 4 THEN oplot,rg[b,ih,id,is,0,j,0]+rg[b,ih,id,is,1,j,0]*D $
                      +rg[b,ih,id,is,2,j,0]*D^2,color=lcol[id],thick=3
                    IF j EQ 5 THEN oplot,rg[b,ih,id,is,0,5,0]+rg[b,ih,id,is,1,j,0]*D $
                      +rg[b,ih,id,is,2,j,0]*D^2+rg[b,ih,id,is,3,j,0]*D^3,color=lcol[id],thick=3
                ENDFOR
                oplot,[L_max[b,0],L_max[b,0]],[-100,10000],symsize=1,color=lcol[1],linestyle=2,thick=3
                oplot,[L_typ[b,0],L_typ[b,0]],[-100,10000],symsize=1,color=lcol[2],linestyle=2,thick=3
                oplot,[L_min[b,0],L_min[b,0]],[-100,10000],symsize=1,color=lcol[3],linestyle=2,thick=3
                
                ; Plot fractional fitting residual in percent.
                xmax2=max(L_max[b,0])
                ymax3=max(100.*dL_fit_1[warm,b,ih,0:detectors[b]-1,0,j,0],min=ymin3)
                
                plot,rad_OBC_x[warm,b,ih,0,is,0],100.*dL_fit_1[warm,b,ih,0,is,j,0],xtit='dL_OBC (Wm-2sr-1um-1)',ytit='dn Residual (%)', $
                  xrange=[0,xmax2],yrange=[ymin3,ymax3],title=title[j-3],charsize=1.2,charthick=5,thick=3,/nodata
                
                FOR id=0, detectors[b]-1 DO BEGIN
                    oplot,rad_OBC_x[warm,b,ih,id,is,0],100.*dL_fit_1[warm,b,ih,id,is,j,0],symsize=1,color=lcol[id],psym=symbol[id],thick=3
                    oplot,rad_OBC_x[warm,b,ih,id,is,0],100.*dL_fit_1[warm,b,ih,id,is,j,0],color=lcol[id],thick=3
                ENDFOR
                oplot,[L_max[b,0],L_max[b,0]],[-100,10000],symsize=1,color=lcol[1],linestyle=2,thick=3
                oplot,[L_typ[b,0],L_typ[b,0]],[-100,10000],symsize=1,color=lcol[2],linestyle=2,thick=3
                oplot,[L_min[b,0],L_min[b,0]],[-100,10000],symsize=1,color=lcol[3],linestyle=2,thick=3
            ENDFOR
            XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
            IF band_type[b] EQ 0 THEN set_legend,1,chname,lcol,symbol
            IF band_type[b] EQ 1 THEN set_legend,2,chname,lcol,symbol
        ENDFOR
    ENDFOR
ENDFOR

device,/close

;*****************************************************************************
;  Plot delta OBC radiance versus dn with fit (quadratic pol_fit)
;  along with the fractional fitting residual.
;*****************************************************************************

set_multicolor,xsave,ysave,psave,chname,lcol,symbol,red,green,blue
set_plot,'ps'
outfname=outpath+a2[a3-3]+'.'+a2[a3-2]+'.'+a2[a3-1]+'.cool_down.fits_1.ps'
device,/landscape,filename=outfname,/color

; Calibration equation.
; Plot all bands on one page, then one band to a page with residual.
title1='dL_OBC vs dn'
FOR ih=0, nham-1 DO BEGIN
    FOR i=0, 1 DO BEGIN
        IF i EQ 0 THEN !p.multi=[0,3,3]
        IF i EQ 1 THEN !p.multi=[0,1,2]
        !p.position=0

        ; Plot dn vs dL_BCS.
        FOR b=0, nbands-1 DO BEGIN
            IF band_type[b] EQ 0 THEN title2=band_name[b]+', HAM= '+HAM[ih]+' (quadratic poly_fit)'
            IF band_type[b] EQ 1 THEN title2=band_name[b]+' SS1, HAM= '+HAM[ih]+' (quadratic poly_fit)'
            
            ymax=max(rad_OBC_x[cool,b,ih,*,0,0])
            xmax=max(dn_1[cool,b,ih,*,0])

            plot,rad_OBC_x[cool,b,ih,1,0,0],dn_1[cool,b,ih,1,0],xrange=[0,ymax],yrange=[0,xmax], $
              xtit='dL_OBC (Wm-2sr-1um-1)',ytit='dn',title=title2,charsize=1.2,charthick=5,thick=3,/nodata
            
            FOR id=0, detectors[b]-1 DO BEGIN
                oplot,rad_OBC_x[cool,b,ih,id,0,0],dn_1[cool,b,ih,id,0],symsize=1,color=lcol[id],psym=symbol[id],thick=3
                ; Use fits from response equation to fit the axes.
                oplot,rg[b,ih,id,0,0,10,0]+rg[b,ih,id,0,1,10,0]*D+rg[b,ih,id,0,2,10,0]*D^2,color=lcol[id],thick=3
            ENDFOR
                oplot,[L_max[b,0],L_max[b,0]],[-100,10000],symsize=1,color=lcol[1],linestyle=2,thick=3
                oplot,[L_typ[b,0],L_typ[b,0]],[-100,10000],symsize=1,color=lcol[2],linestyle=2,thick=3
                oplot,[L_min[b,0],L_min[b,0]],[-100,10000],symsize=1,color=lcol[3],linestyle=2,thick=3
            
            XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5

            ; Plot fractional fitting residual in percent.
            IF i EQ 1 THEN BEGIN
                ymax=max(100.*dL_fit_1[cool,b,ih,0:detectors[b]-1,0,7,0],min=ymin)

                plot,rad_OBC_x[cool,b,ih,0,is,0],100.*dL_fit_1[cool,b,ih,0,0,7,0],xtit='dL_OBC (Wm-2sr-1um-1)',ytit='Radiance Residual (%)', $
                  xrange=[0,L_max[b,0]],yrange=[ymin,ymax],title=title1,charsize=1.2,charthick=5,thick=3,/nodata
                
                FOR id=0, detectors[b]-1 DO BEGIN
                    oplot,rad_OBC_x[cool,b,ih,id,0,0],100.*dL_fit_1[cool,b,ih,id,0,7,0],symsize=1,color=lcol[id],psym=symbol[id],thick=3
                    oplot,rad_OBC_x[cool,b,ih,id,0,0],100.*dL_fit_1[cool,b,ih,id,0,7,0],color=lcol[id],thick=3
                ENDFOR
                oplot,[L_max[b,0],L_max[b,0]],[-100,10000],symsize=1,color=lcol[1],linestyle=2,thick=3
                oplot,[L_typ[b,0],L_typ[b,0]],[-100,10000],symsize=1,color=lcol[2],linestyle=2,thick=3
                oplot,[L_min[b,0],L_min[b,0]],[-100,10000],symsize=1,color=lcol[3],linestyle=2,thick=3

                XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
                IF band_type[b] EQ 0 THEN set_legend,1,chname,lcol,symbol
                IF band_type[b] EQ 1 THEN set_legend,2,chname,lcol,symbol
            ENDIF
        ENDFOR
    ENDFOR
ENDFOR

; Response equation.
; Plot all bands on one page, then one band to a page with residual.
title1='dn vs dL_OBC'
FOR ih=0, nham-1 DO BEGIN
    FOR i=0, 1 DO BEGIN
        IF i EQ 0 THEN !p.multi=[0,3,3]
        IF i EQ 1 THEN !p.multi=[0,1,2]
        !p.position=0

        ; Plot dn vs dL_OBC.
        FOR b=0, nbands-1 DO BEGIN
            IF band_type[b] EQ 0 THEN title2=band_name[b]+', HAM= '+HAM[ih]+' (quadratic poly_fit)'
            IF band_type[b] EQ 1 THEN title2=band_name[b]+' SS1, HAM= '+HAM[ih]+' (quadratic poly_fit)'
            
            xmax=max(rad_OBC_x[cool,b,ih,*,0,0])
            ymax=max(dn_1[cool,b,ih,*,0])
            
            plot,rad_OBC_x[cool,b,ih,1,0,0],dn_1[cool,b,ih,1,0],yrange=[0,ymax],xrange=[0,xmax], $
              xtit='dL_OBC (Wm-2sr-1um-1)',ytit='dn',title=title2,charsize=1.2,charthick=5,thick=3,/nodata
            
            FOR id=0, detectors[b]-1 DO BEGIN
                oplot,rad_OBC_x[cool,b,ih,id,0,0],dn_1[cool,b,ih,id,0],symsize=1,color=lcol[id],psym=symbol[id],thick=3
                oplot,rg[b,ih,id,0,0,10,0]+rg[b,ih,id,0,1,10,0]*D+rg[b,ih,id,0,2,10,0]*D^2,color=lcol[id],thick=3
            ENDFOR
            oplot,[L_max[b,0],L_max[b,0]],[-100,10000],symsize=1,color=lcol[1],linestyle=2,thick=3
            oplot,[L_typ[b,0],L_typ[b,0]],[-100,10000],symsize=1,color=lcol[2],linestyle=2,thick=3
            oplot,[L_min[b,0],L_min[b,0]],[-100,10000],symsize=1,color=lcol[3],linestyle=2,thick=3
            
            XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5

            ; Plot fractional fitting residual in percent.
            IF i EQ 1 THEN BEGIN
                ymax=max(100.*dL_fit_1[cool,b,ih,0:detectors[b]-1,0,10,0],min=ymin)
                
                plot,rad_OBC_x[cool,b,ih,0,is,0],100*dL_fit_1[cool,b,ih,0,0,10,0],xtit='dL_OBC (Wm-2sr-1um-1)',ytit='dn Residual (%)', $
                  xrange=[0,L_max[b,0]],yrange=[ymin,ymax],title=title1,charsize=1.2,charthick=5,thick=3,/nodata
                
                FOR id=0, detectors[b]-1 DO BEGIN
                    oplot,rad_OBC_x[cool,b,ih,id,0,0],100.*dL_fit_1[cool,b,ih,id,0,10,0],symsize=1,color=lcol[id],psym=symbol[id],thick=3
                    oplot,rad_OBC_x[cool,b,ih,id,0,0],100.*dL_fit_1[cool,b,ih,id,0,10,0],color=lcol[id],thick=3
                ENDFOR
                oplot,[L_max[b,0],L_max[b,0]],[-100,10000],symsize=1,color=lcol[1],linestyle=2,thick=3
                oplot,[L_typ[b,0],L_typ[b,0]],[-100,10000],symsize=1,color=lcol[2],linestyle=2,thick=3
                oplot,[L_min[b,0],L_min[b,0]],[-100,10000],symsize=1,color=lcol[3],linestyle=2,thick=3

                XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
                IF band_type[b] EQ 0 THEN set_legend,1,chname,lcol,symbol
                IF band_type[b] EQ 1 THEN set_legend,2,chname,lcol,symbol
            ENDIF
        ENDFOR
    ENDFOR
ENDFOR

device,/close

;*****************************************************************************
;  Plot delta OBC radiance versus dn with fits (linear poly_fit, quadratic pol_fit,
;  and cubic poly_fit).
;*****************************************************************************

set_multicolor,xsave,ysave,psave,chname,lcol,symbol,red,green,blue
set_plot,'ps'
outfname=outpath+a2[a3-3]+'.'+a2[a3-2]+'.'+a2[a3-1]+'.cool_down.fits_2.ps'
device,/landscape,filename=outfname,/color

title=strarr(4)

!p.multi=[0,2,3]

; Calibration equation.
FOR b=0, nbands-1 DO BEGIN
    !p.position=0

    FOR is=0, subsets[b]-1 DO BEGIN
        FOR ih=0, nham-1 DO BEGIN
            IF band_type[b] EQ 0 THEN BEGIN
                title1=band_name[b]+': dL_OBC vs dn'
                title[0]=band_name[b]+', HAM= '+HAM[ih]+' (linear poly_fit)'
                title[1]=band_name[b]+', HAM= '+HAM[ih]+' (quadratic poly_fit)'
                title[2]=band_name[b]+', HAM= '+HAM[ih]+' (cubic poly_fit)'
            ENDIF
            IF band_type[b] EQ 1 THEN BEGIN
                title1=band_name[b]+SS[is]+': dL_OBC vs dn'
                title[0]=band_name[b]+SS[is]+', '+'HAM= '+HAM[ih]+' (linear poly_fit)'
                title[1]=band_name[b]+SS[is]+', '+'HAM= '+HAM[ih]+' (quadratic poly_fit)'
                title[2]=band_name[b]+SS[is]+', '+'HAM= '+HAM[ih]+' (cubic poly_fit)'
            ENDIF
            
            ; Plot dL_BCS vs dn.
            xmax=max(L_max[b,0])
            ymax=max(dn_1[cool,b,ih,*,is])
            
            FOR j=6, 8 DO BEGIN
                plot,rad_OBC_x[cool,b,ih,1,is,0],dn_1[cool,b,ih,1,is],yrange=[0,ymax],xrange=[0,xmax], $
                  xtit='dL_OBC (Wm-2sr-1um-1)',ytit='dn',title=title[j-6],charsize=1.2,charthick=5,thick=3,/nodata
                
                FOR id=0, detectors[b]-1 DO BEGIN
                    oplot,rad_OBC_x[cool,b,ih,id,is,0],dn_1[cool,b,ih,id,is],symsize=1,color=lcol[id],psym=symbol[id],thick=3
                    IF j EQ 0 THEN oplot,rg[b,ih,id,is,0,j+3,0]+rg[b,ih,id,is,1,j+3,0]*D,color=lcol[id],thick=3
                    IF j EQ 1 THEN oplot,rg[b,ih,id,is,0,j+3,0]+rg[b,ih,id,is,1,j+3,0]*D $
                      +rg[b,ih,id,is,2,j+3,0]*D^2,color=lcol[id],thick=3
                    IF j EQ 2 THEN oplot,rg[b,ih,id,is,0,j+3,0]+rg[b,ih,id,is,1,j+3,0]*D $
                      +rg[b,ih,id,is,2,j+3,0]*D^2+rg[b,ih,id,is,3,j+3,0]*D^3,color=lcol[id],thick=3
                ENDFOR
                oplot,[L_max[b,0],L_max[b,0]],[-100,10000],symsize=1,color=lcol[1],linestyle=2,thick=3
                oplot,[L_typ[b,0],L_typ[b,0]],[-100,10000],symsize=1,color=lcol[2],linestyle=2,thick=3
                oplot,[L_min[b,0],L_min[b,0]],[-100,10000],symsize=1,color=lcol[3],linestyle=2,thick=3
                
                ; Plot fractional fitting residual in percent.
                xmax2=max(L_max[b,0])
                ymax3=max(100.*dL_fit_1[cool,b,ih,0:detectors[b]-1,0,j,0],min=ymin3)
                
                plot,rad_OBC_x[cool,b,ih,0,is,0],100.*dL_fit_1[cool,b,ih,0,is,j,0],xtit='dL_OBC (Wm-2sr-1um-1)',ytit='Radiance Residual (%)', $
                  xrange=[0,xmax2],yrange=[ymin3,ymax3],title=title[j-6],charsize=1.2,charthick=5,thick=3,/nodata
                
                FOR id=0, detectors[b]-1 DO BEGIN
                    oplot,rad_OBC_x[cool,b,ih,id,is,0],100.*dL_fit_1[cool,b,ih,id,is,j,0],symsize=1,color=lcol[id],psym=symbol[id],thick=3
                    oplot,rad_OBC_x[cool,b,ih,id,is,0],100.*dL_fit_1[cool,b,ih,id,is,j,0],color=lcol[id],thick=3
                ENDFOR
                oplot,[L_max[b,0],L_max[b,0]],[-100,10000],symsize=1,color=lcol[1],linestyle=2,thick=3
                oplot,[L_typ[b,0],L_typ[b,0]],[-100,10000],symsize=1,color=lcol[2],linestyle=2,thick=3
                oplot,[L_min[b,0],L_min[b,0]],[-100,10000],symsize=1,color=lcol[3],linestyle=2,thick=3
            ENDFOR
            XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
            IF band_type[b] EQ 0 THEN set_legend,1,chname,lcol,symbol
            IF band_type[b] EQ 1 THEN set_legend,2,chname,lcol,symbol
        ENDFOR
    ENDFOR
ENDFOR

; Response equation.
FOR b=0, nbands-1 DO BEGIN
    !p.position=0

    FOR is=0, subsets[b]-1 DO BEGIN
        FOR ih=0, nham-1 DO BEGIN
            IF band_type[b] EQ 0 THEN BEGIN
                title1=band_name[b]+': dn vs dL_OBC'
                title[0]=band_name[b]+', HAM= '+HAM[ih]+' (linear poly_fit)'
                title[1]=band_name[b]+', HAM= '+HAM[ih]+' (quadratic poly_fit)'
                title[2]=band_name[b]+', HAM= '+HAM[ih]+' (cubic poly_fit)'
            ENDIF
            IF band_type[b] EQ 1 THEN BEGIN
                title1=band_name[b]+SS[is]+': dn vs dL_OBC'
                title[0]=band_name[b]+SS[is]+', '+'HAM= '+HAM[ih]+' (linear poly_fit)'
                title[1]=band_name[b]+SS[is]+', '+'HAM= '+HAM[ih]+' (quadratic poly_fit)'
                title[2]=band_name[b]+SS[is]+', '+'HAM= '+HAM[ih]+' (cubic poly_fit)'
            ENDIF
            
            ; Plot dn vs dL_BCS.
            xmax=max(L_max[b,0])
            ymax=max(dn_1[cool,b,ih,*,is])
            
            FOR j=9, 11 DO BEGIN
                plot,rad_OBC_x[cool,b,ih,1,is,0],dn_1[cool,b,ih,1,is],yrange=[0,ymax],xrange=[0,xmax], $
                  xtit='dL_OBC (Wm-2sr-1um-1)',ytit='dn',title=title[j-9],charsize=1.2,charthick=5,thick=3,/nodata
                
                FOR id=0, detectors[b]-1 DO BEGIN
                    oplot,rad_OBC_x[cool,b,ih,id,is,0],dn_1[cool,b,ih,id,is],symsize=1,color=lcol[id],psym=symbol[id],thick=3
                    IF j EQ 3 THEN oplot,rg[b,ih,id,is,0,j,0]+rg[b,ih,id,is,1,j,0]*D,color=lcol[id],thick=3
                    IF j EQ 4 THEN oplot,rg[b,ih,id,is,0,j,0]+rg[b,ih,id,is,1,j,0]*D $
                      +rg[b,ih,id,is,2,j,0]*D^2,color=lcol[id],thick=3
                    IF j EQ 5 THEN oplot,rg[b,ih,id,is,0,5,0]+rg[b,ih,id,is,1,j,0]*D $
                      +rg[b,ih,id,is,2,j,0]*D^2+rg[b,ih,id,is,3,j,0]*D^3,color=lcol[id],thick=3
                ENDFOR
                oplot,[L_max[b,0],L_max[b,0]],[-100,10000],symsize=1,color=lcol[1],linestyle=2,thick=3
                oplot,[L_typ[b,0],L_typ[b,0]],[-100,10000],symsize=1,color=lcol[2],linestyle=2,thick=3
                oplot,[L_min[b,0],L_min[b,0]],[-100,10000],symsize=1,color=lcol[3],linestyle=2,thick=3
                
                ; Plot fractional fitting residual in percent.
                xmax2=max(L_max[b,0])
                ymax3=max(100.*dL_fit_1[cool,b,ih,0:detectors[b]-1,0,j,0],min=ymin3)
                
                plot,rad_OBC_x[cool,b,ih,0,is,0],100.*dL_fit_1[cool,b,ih,0,is,j,0]/dn_1[cool,b,ih,0,is],xtit='dL_OBC (Wm-2sr-1um-1)',ytit='dn Residual (%)', $
                  xrange=[0,xmax2],yrange=[ymin3,ymax3],title=title[j-9],charsize=1.2,charthick=5,thick=3,/nodata
                
                FOR id=0, detectors[b]-1 DO BEGIN
                    oplot,rad_OBC_x[cool,b,ih,id,is,0],100.*dL_fit_1[cool,b,ih,id,is,j,0],symsize=1,color=lcol[id],psym=symbol[id],thick=3
                    oplot,rad_OBC_x[cool,b,ih,id,is,0],100.*dL_fit_1[cool,b,ih,id,is,j,0],color=lcol[id],thick=3
                ENDFOR
                oplot,[L_max[b,0],L_max[b,0]],[-100,10000],symsize=1,color=lcol[1],linestyle=2,thick=3
                oplot,[L_typ[b,0],L_typ[b,0]],[-100,10000],symsize=1,color=lcol[2],linestyle=2,thick=3
                oplot,[L_min[b,0],L_min[b,0]],[-100,10000],symsize=1,color=lcol[3],linestyle=2,thick=3
            ENDFOR
            XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
            IF band_type[b] EQ 0 THEN set_legend,1,chname,lcol,symbol
            IF band_type[b] EQ 1 THEN set_legend,2,chname,lcol,symbol
        ENDFOR
    ENDFOR
ENDFOR

device,/close

;*****************************************************************************
;  Radiometric response characterization uncertainty (RRCU)
;  (SRV0448). Warm-up.
;*****************************************************************************

set_multicolor,xsave,ysave,psave,chname,lcol,symbol,red,green,blue
set_plot,'ps'
outfname=outpath+a2[a3-3]+'.'+a2[a3-2]+'.'+a2[a3-1]+'.warm_up.RRCU.ps'
device,/landscape,filename=outfname,/color

!p.multi=[0,1,1]

; Plot the RRCU, one band per page.
title1='RRCU vs Detector (SRV0448) warm-up'
FOR b=0, nbands-1 DO BEGIN
    !p.position=0
    
    title2=band_name[b]
        
    ymax=max(rrcu[b,*,0:detectors[b]-1,*,0,0])
    IF ymax LT 0.001 THEN ymax=0.0011
    plot,E[0:detectors[b]-1]+1,rrcu[b,0,0:detectors[b]-1,0,0,0],xtit='Detectors',ytit='RRCU',xrange=[0,detectors[b]+2],yrange=[0,ymax],title=title2, $
      charsize=1.2,charthick=5,thick=3,/nodata
        
    j=0
    FOR is=0, subsets[b]-1 DO BEGIN
        FOR ih=0, nham-1 DO BEGIN
            oplot,E[0:detectors[b]-1]+1,rrcu[b,ih,0:detectors[b]-1,is,0,0],symsize=1,color=lcol[j],psym=symbol[j],thick=3
            oplot,E[0:detectors[b]-1]+1,rrcu[b,ih,0:detectors[b]-1,is,0,0],color=lcol[j],thick=3
            j=j+1
        ENDFOR
    ENDFOR
    oplot,[0,100],[0.001,0.001],color=lcol[1],linestyle=2,thick=3
    
    XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
    set_legend,1,HAM_SS,lcol,symbol
ENDFOR

!p.multi=[0,2,2]

; Plot the RRCU, four bands per page.
FOR b=0, nbands-1 DO BEGIN
    !p.position=0
        
    title2=band_name[b]
    
    ymax=max(rrcu[b,*,0:detectors[b]-1,*,0,0])
    IF ymax LT 0.001 THEN ymax=0.0011
    plot,E[0:detectors[b]-1]+1,rrcu[b,0,0:detectors[b]-1,0,0,0],xtit='Detectors',ytit='RRCU',xrange=[0,detectors[b]+2],yrange=[0,ymax],title=title2, $
      charsize=1.2,charthick=5,thick=3,/nodata

    j=0
    FOR is=0, subsets[b]-1 DO BEGIN
        FOR ih=0, nham-1 DO BEGIN
            oplot,E[0:detectors[b]-1]+1,rrcu[b,ih,0:detectors[b]-1,is,0,0],symsize=1,color=lcol[j],psym=symbol[j],thick=3
            oplot,E[0:detectors[b]-1]+1,rrcu[b,ih,0:detectors[b]-1,is,0,0],color=lcol[j],thick=3
            j=j+1
        ENDFOR
    ENDFOR
    oplot,[0,100],[0.001,0.001],color=lcol[1],linestyle=2,thick=3
    
    XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
ENDFOR

device,/close

;*****************************************************************************
;  Radiometric response characterization uncertainty (RRCU)
;  (SRV0448). Cool-down.
;*****************************************************************************

set_multicolor,xsave,ysave,psave,chname,lcol,symbol,red,green,blue
set_plot,'ps'
outfname=outpath+a2[a3-3]+'.'+a2[a3-2]+'.'+a2[a3-1]+'.cool_down.RRCU.ps'
device,/landscape,filename=outfname,/color

!p.multi=[0,1,1]

; Plot the RRCU, one band per page.
title1='RRCU vs Detector (SRV0448) cool-down'
FOR b=0, nbands-1 DO BEGIN
    !p.position=0
    
    title2=band_name[b]
        
    ymax=max(rrcu[b,*,0:detectors[b]-1,*,0,1])
    IF ymax LT 0.001 THEN ymax=0.0011
    plot,E[0:detectors[b]-1]+1,rrcu[b,0,0:detectors[b]-1,0,0,1],xtit='Detectors',ytit='RRCU',xrange=[0,detectors[b]+2],yrange=[0,ymax],title=title2, $
      charsize=1.2,charthick=5,thick=3,/nodata
        
    j=0
    FOR is=0, subsets[b]-1 DO BEGIN
        FOR ih=0, nham-1 DO BEGIN
            oplot,E[0:detectors[b]-1]+1,rrcu[b,ih,0:detectors[b]-1,is,0,1],symsize=1,color=lcol[j],psym=symbol[j],thick=3
            oplot,E[0:detectors[b]-1]+1,rrcu[b,ih,0:detectors[b]-1,is,0,1],color=lcol[j],thick=3
            j=j+1
        ENDFOR
    ENDFOR
    oplot,[0,100],[0.001,0.001],color=lcol[1],linestyle=2,thick=3
    
    XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
    set_legend,1,HAM_SS,lcol,symbol
ENDFOR

!p.multi=[0,2,2]

; Plot the RRCU, four bands per page.
FOR b=0, nbands-1 DO BEGIN
    !p.position=0
        
    title2=band_name[b]
    
    ymax=max(rrcu[b,*,0:detectors[b]-1,*,0,1])
    IF ymax LT 0.001 THEN ymax=0.0011
    plot,E[0:detectors[b]-1]+1,rrcu[b,0,0:detectors[b]-1,0,0,1],xtit='Detectors',ytit='RRCU',xrange=[0,detectors[b]+2],yrange=[0,ymax],title=title2, $
      charsize=1.2,charthick=5,thick=3,/nodata

    j=0
    FOR is=0, subsets[b]-1 DO BEGIN
        FOR ih=0, nham-1 DO BEGIN
            oplot,E[0:detectors[b]-1]+1,rrcu[b,ih,0:detectors[b]-1,is,0,1],symsize=1,color=lcol[j],psym=symbol[j],thick=3
            oplot,E[0:detectors[b]-1]+1,rrcu[b,ih,0:detectors[b]-1,is,0,1],color=lcol[j],thick=3
            j=j+1
        ENDFOR
    ENDFOR
    oplot,[0,100],[0.001,0.001],color=lcol[1],linestyle=2,thick=3
    
    XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
ENDFOR

device,/close

;*****************************************************************************
;  Radiometric response non-linearity (RRNL) (SRV0595). Warm-up.
;*****************************************************************************

set_multicolor,xsave,ysave,psave,chname,lcol,symbol,red,green,blue
set_plot,'ps'
outfname=outpath+a2[a3-3]+'.'+a2[a3-2]+'.'+a2[a3-1]+'.warm_up.RRNL.ps'
device,/landscape,filename=outfname,/color

!p.multi=[0,1,1]

; Plot the RRNL, one band per page.
title1='RRNL vs Detector (SRV0595) warm-up'
FOR b=0, nbands-1 DO BEGIN
    !p.position=0

    title2=band_name[b]+' (linear poly_fit)'

    ymax=max(rrnl[b,*,*,*,0,0])
    IF ymax LT 0.01 AND band_type[b] EQ 0 THEN ymax=0.011
    IF ymax LT 0.01 AND band_type[b] EQ 1 THEN ymax=0.013

    plot,E[0:detectors[b]-1]+1,rrnl[b,0,0:detectors[b]-1,0,0,0],xtit='Detectors',ytit='RRNL',xrange=[0,detectors[b]+2],yrange=[0,ymax],title=title2, $
      charsize=1.2,charthick=5,thick=3,/nodata

    j=0
    FOR is=0, subsets[b]-1 DO BEGIN
        FOR ih=0, nham-1 DO BEGIN
            oplot,E[0:detectors[b]-1]+1,rrnl[b,ih,0:detectors[b]-1,is,0,0],symsize=1,color=lcol[j],psym=symbol[j],thick=3
            oplot,E[0:detectors[b]-1]+1,rrnl[b,ih,0:detectors[b]-1,is,0,0],color=lcol[j],thick=3
            j=j+1
        ENDFOR
    ENDFOR
    oplot,[0,100],[0.01,0.01],color=lcol[1],linestyle=2,thick=3

    XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
    set_legend,1,HAM_SS,lcol,symbol
ENDFOR

!p.multi=[0,2,2]
!p.position=0

; Plot the RRNL, four bands per page.
FOR b=0, nbands-1 DO BEGIN
    title2=band_name[b]+' (linear poly_fit)'

    ymax=max(rrnl[b,*,*,*,0,0])
    IF ymax LT 0.01 AND band_type[b] EQ 0 THEN ymax=0.011
    IF ymax LT 0.01 AND band_type[b] EQ 1 THEN ymax=0.013
    
    plot,E[0:detectors[b]-1]+1,rrnl[b,0,0:detectors[b]-1,0,0,0],xtit='Detectors',ytit='RRNL',xrange=[0,detectors[b]+2],yrange=[0,ymax],title=title2, $
      charsize=1.2,charthick=5,thick=3,/nodata
    
    j=0
    FOR is=0, subsets[b]-1 DO BEGIN
        FOR ih=0, nham-1 DO BEGIN
            oplot,E[0:detectors[b]-1]+1,rrnl[b,ih,0:detectors[b]-1,is,0,0],symsize=1,color=lcol[j],psym=symbol[j],thick=3
            oplot,E[0:detectors[b]-1]+1,rrnl[b,ih,0:detectors[b]-1,is,0,0],color=lcol[j],thick=3
            j=j+1
        ENDFOR
    ENDFOR
    oplot,[0,100],[0.01,0.01],color=lcol[1],linestyle=2,thick=3
    
    XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
    set_legend,1,HAM_SS,lcol,symbol
ENDFOR

device,/close

;*****************************************************************************
;  Radiometric response non-linearity (RRNL) (SRV0595). Cool-down.
;*****************************************************************************

set_multicolor,xsave,ysave,psave,chname,lcol,symbol,red,green,blue
set_plot,'ps'
outfname=outpath+a2[a3-3]+'.'+a2[a3-2]+'.'+a2[a3-1]+'.cool_down.RRNL.ps'
device,/landscape,filename=outfname,/color

!p.multi=[0,1,1]

; Plot the RRNL, one band per page.
title1='RRNL vs Detector (SRV0595) cool-down'
FOR b=0, nbands-1 DO BEGIN
    !p.position=0

    title2=band_name[b]+' (linear poly_fit)'

    ymax=max(rrnl[b,*,*,*,0,1])
    IF ymax LT 0.01 AND band_type[b] EQ 0 THEN ymax=0.011
    IF ymax LT 0.01 AND band_type[b] EQ 1 THEN ymax=0.013

    plot,E[0:detectors[b]-1]+1,rrnl[b,0,0:detectors[b]-1,0,0,1],xtit='Detectors',ytit='RRNL',xrange=[0,detectors[b]+2],yrange=[0,ymax],title=title2, $
      charsize=1.2,charthick=5,thick=3,/nodata

    j=0
    FOR is=0, subsets[b]-1 DO BEGIN
        FOR ih=0, nham-1 DO BEGIN
            oplot,E[0:detectors[b]-1]+1,rrnl[b,ih,0:detectors[b]-1,is,0,1],symsize=1,color=lcol[j],psym=symbol[j],thick=3
            oplot,E[0:detectors[b]-1]+1,rrnl[b,ih,0:detectors[b]-1,is,0,1],color=lcol[j],thick=3
            j=j+1
        ENDFOR
    ENDFOR
    oplot,[0,100],[0.01,0.01],color=lcol[1],linestyle=2,thick=3

    XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
    set_legend,1,HAM_SS,lcol,symbol
ENDFOR

!p.multi=[0,2,2]
!p.position=0

; Plot the RRNL, four bands per page.
FOR b=0, nbands-1 DO BEGIN
    title2=band_name[b]+' (linear poly_fit)'

    ymax=max(rrnl[b,*,*,*,0,1])
    IF ymax LT 0.01 AND band_type[b] EQ 0 THEN ymax=0.011
    IF ymax LT 0.01 AND band_type[b] EQ 1 THEN ymax=0.013
    
    plot,E[0:detectors[b]-1]+1,rrnl[b,0,0:detectors[b]-1,0,0,1],xtit='Detectors',ytit='RRNL',xrange=[0,detectors[b]+2],yrange=[0,ymax],title=title2, $
      charsize=1.2,charthick=5,thick=3,/nodata
    
    j=0
    FOR is=0, subsets[b]-1 DO BEGIN
        FOR ih=0, nham-1 DO BEGIN
            oplot,E[0:detectors[b]-1]+1,rrnl[b,ih,0:detectors[b]-1,is,0,1],symsize=1,color=lcol[j],psym=symbol[j],thick=3
            oplot,E[0:detectors[b]-1]+1,rrnl[b,ih,0:detectors[b]-1,is,0,1],color=lcol[j],thick=3
            j=j+1
        ENDFOR
    ENDFOR
    oplot,[0,100],[0.01,0.01],color=lcol[1],linestyle=2,thick=3
    
    XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
    set_legend,1,HAM_SS,lcol,symbol
ENDFOR

device,/close

;*****************************************************************************
;  Plot delta OBC radiance versus dn with fit (quadratic pol_fit)
;  along with the fractional fitting residual.
;*****************************************************************************

set_multicolor,xsave,ysave,psave,chname,lcol,symbol,red,green,blue
set_plot,'ps'
outfname=outpath+a2[a3-3]+'.'+a2[a3-2]+'.'+a2[a3-1]+'.fits_1.ps'
device,/landscape,filename=outfname,/color

; Response equation.
; Plot all bands on one page, then one band to a page with residual.
FOR ih=0, nham-1 DO BEGIN
        !p.multi=[0,1,1]
        !p.position=0

        ; Plot dn vs dL_OBC.
        FOR b=0, nbands-1 DO BEGIN
            IF band_type[b] EQ 0 THEN title2=band_name[b]+', HAM= '+HAM[ih]+' (quadratic poly_fit)'
            IF band_type[b] EQ 1 THEN title2=band_name[b]+' SS1, HAM= '+HAM[ih]+' (quadratic poly_fit)'
            
            xmax=max(rad_OBC_x[cool,b,ih,*,0,0])
            ymax=max(dn_1[cool,b,ih,*,0])
            
            plot,rad_OBC_x[cool,b,ih,1,0,0],dn_1[cool,b,ih,1,0],yrange=[0,ymax],xrange=[0,xmax], $
              xtit='dL_OBC (Wm-2sr-1um-1)',ytit='dn',title=title2,charsize=1.2,charthick=5,thick=3,/nodata
            
            FOR id=0, detectors[b]-1 DO BEGIN
if id ne 8 then continue
                oplot,rad_OBC_x[warm,b,ih,id,0,0],dn_1[warm,b,ih,id,0],symsize=1,color=lcol[id],psym=symbol[id],thick=3
                oplot,rg[b,ih,id,0,0,4,0]+rg[b,ih,id,0,1,4,0]*D+rg[b,ih,id,0,2,4,0]*D^2,color=lcol[id],thick=3
            ;    oplot,rad_OBC_x[warm,b,ih,id,0,0],dn_1[warm,b,ih,id,0],symsize=1,color=lcol[id],thick=3

                oplot,rad_OBC_x[cool,b,ih,id,0,0],dn_1[cool,b,ih,id,0],symsize=1,color=lcol[id+1],psym=symbol[id+1],thick=3
                oplot,rg[b,ih,id,0,0,10,0]+rg[b,ih,id,0,1,10,0]*D+rg[b,ih,id,0,2,10,0]*D^2,color=lcol[id+1],thick=3
             ;   oplot,rad_OBC_x[cool,b,ih,id,0,0],dn_1[cool,b,ih,id,0],symsize=1,color=lcol[id+1],thick=3
            ENDFOR
            oplot,[L_max[b,0],L_max[b,0]],[-100,10000],symsize=1,color=lcol[1],linestyle=2,thick=3
            oplot,[L_typ[b,0],L_typ[b,0]],[-100,10000],symsize=1,color=lcol[2],linestyle=2,thick=3
            oplot,[L_min[b,0],L_min[b,0]],[-100,10000],symsize=1,color=lcol[3],linestyle=2,thick=3
        ENDFOR
ENDFOR

device,/close

END
